# coding: utf-8

# flake8: noqa
"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

# import models into model package
from .all_of_i18n_string_lang import AllOfI18nStringLang
from .article import Article
from .article_preview import ArticlePreview
from .article_share import ArticleShare
from .article_with_layout import ArticleWithLayout
from .attached_link import AttachedLink
from .base_block import BaseBlock
from .block_cascade import BlockCascade
from .block_client_computed import BlockClientComputed
from .block_community_preview import BlockCommunityPreview
from .block_directory_entry import BlockDirectoryEntry
from .block_event_metadata import BlockEventMetadata
from .block_featured_image import BlockFeaturedImage
from .block_generic_container import BlockGenericContainer
from .block_generic_resource import BlockGenericResource
from .block_grid import BlockGrid
from .block_html import BlockHtml
from .block_image import BlockImage
from .block_inappropriate import BlockInappropriate
from .block_intro import BlockIntro
from .block_list import BlockList
from .block_no_results import BlockNoResults
from .block_page_preview import BlockPagePreview
from .block_post import BlockPost
from .block_reactions import BlockReactions
from .block_remote import BlockRemote
from .block_resource_creation_info import BlockResourceCreationInfo
from .block_slideshow import BlockSlideshow
from .block_structured_content import BlockStructuredContent
from .block_tab_filtered_container import BlockTabFilteredContainer
from .block_tag_filter import BlockTagFilter
from .block_tag_reference_list import BlockTagReferenceList
from .block_title import BlockTitle
from .block_type import BlockType
from .block_user import BlockUser
from .block_user_list import BlockUserList
from .block_user_profile_preview import BlockUserProfilePreview
from .block_votes import BlockVotes
from .community_info import CommunityInfo
from .container_orientation import ContainerOrientation
from .container_reference import ContainerReference
from .container_type import ContainerType
from .container_variant import ContainerVariant
from .content_status import ContentStatus
from .create_article_in_container_request import CreateArticleInContainerRequest
from .create_event_in_container_request import CreateEventInContainerRequest
from .create_or_update_article_request import CreateOrUpdateArticleRequest
from .create_or_update_event_request import CreateOrUpdateEventRequest
from .custom_link_label import CustomLinkLabel
from .document import Document
from .element_style import ElementStyle
from .error import Error
from .error_links import ErrorLinks
from .error_source import ErrorSource
from .event import Event
from .event_link_label import EventLinkLabel
from .event_page import EventPage
from .event_share import EventShare
from .footer import Footer
from .get_attendees_response import GetAttendeesResponse
from .get_by_id_error import GetByIdError
from .get_by_id_errors import GetByIdErrors
from .get_events_by_ids import GetEventsByIds
from .header import Header
from .i18n_string import I18nString
from .idea_status import IdeaStatus
from .inline_response401 import InlineResponse401
from .language import Language
from .layout import Layout
from .link_label import LinkLabel
from .media_preview import MediaPreview
from .metadata_reference import MetadataReference
from .multilang_document import MultilangDocument
from .multilang_object import MultilangObject
from .one_of_create_event_in_container_request_external_url_label import (
    OneOfCreateEventInContainerRequestExternalUrlLabel,
)
from .one_of_create_or_update_event_request_external_url_label import (
    OneOfCreateOrUpdateEventRequestExternalUrlLabel,
)
from .one_of_event_external_url_label import OneOfEventExternalUrlLabel
from .one_of_widget_body import OneOfWidgetBody
from .organizer_ids import OrganizerIds
from .play_video_preview import PlayVideoPreview
from .post_share import PostShare
from .site_reference import SiteReference
from .slideshow_variant import SlideshowVariant
from .structured_content import StructuredContent
from .tag_reference import TagReference
from .user_profile_field import UserProfileField
from .user_profile_field_type import UserProfileFieldType
from .user_profile_primary_field_values import UserProfilePrimaryFieldValues
from .user_reference import UserReference
from .widget import Widget
from .widget_response import WidgetResponse
from .widget_type import WidgetType



from lumapps.latest.api.exceptions import ApiException
from lumapps.latest.client import IClient, Request

from ..serialization import Serialization
from . import models


class ContributionV1GW(object):
    def __init__(self, client: IClient) -> None:
        self.client = client

    def get_article(self, article_id: str) -> models.Article:
        request = Request(
            method="GET",
            url=f"/articles/{article_id}",
        )
        response = self.client.request(request)
        if response.status_code == 200:
            return Serialization(models).deserialize(response.json, models.Article)
        else:
            raise ApiException(
                Serialization(models)
                .deserialize(response.json["errors"][0], models.Error)
                .detail,
            )



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class UserProfileField(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "definition_id": "str",
        "name": "str",
        "type": "UserProfileFieldType",
        "icon_class": "str",
        "values": "list[str]",
    }

    attribute_map = {
        "definition_id": "definition_id",
        "name": "name",
        "type": "type",
        "icon_class": "iconClass",
        "values": "values",
    }

    def __init__(
        self, definition_id=None, name=None, type=None, icon_class=None, values=None
    ):  # noqa: E501
        """UserProfileField - a model defined in Swagger"""  # noqa: E501
        self._definition_id = None
        self._name = None
        self._type = None
        self._icon_class = None
        self._values = None
        self.discriminator = None
        self.definition_id = definition_id
        self.name = name
        self.type = type
        self.icon_class = icon_class
        self.values = values

    @property
    def definition_id(self):
        """Gets the definition_id of this UserProfileField.  # noqa: E501

        The field's definition id.  # noqa: E501

        :return: The definition_id of this UserProfileField.  # noqa: E501
        :rtype: str
        """
        return self._definition_id

    @definition_id.setter
    def definition_id(self, definition_id):
        """Sets the definition_id of this UserProfileField.

        The field's definition id.  # noqa: E501

        :param definition_id: The definition_id of this UserProfileField.  # noqa: E501
        :type: str
        """
        if definition_id is None:
            raise ValueError(
                "Invalid value for `definition_id`, must not be `None`"
            )  # noqa: E501

        self._definition_id = definition_id

    @property
    def name(self):
        """Gets the name of this UserProfileField.  # noqa: E501

        the translated field name.  # noqa: E501

        :return: The name of this UserProfileField.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UserProfileField.

        the translated field name.  # noqa: E501

        :param name: The name of this UserProfileField.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError(
                "Invalid value for `name`, must not be `None`"
            )  # noqa: E501

        self._name = name

    @property
    def type(self):
        """Gets the type of this UserProfileField.  # noqa: E501


        :return: The type of this UserProfileField.  # noqa: E501
        :rtype: UserProfileFieldType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this UserProfileField.


        :param type: The type of this UserProfileField.  # noqa: E501
        :type: UserProfileFieldType
        """
        if type is None:
            raise ValueError(
                "Invalid value for `type`, must not be `None`"
            )  # noqa: E501

        self._type = type

    @property
    def icon_class(self):
        """Gets the icon_class of this UserProfileField.  # noqa: E501

        the field's icon CSS class.  # noqa: E501

        :return: The icon_class of this UserProfileField.  # noqa: E501
        :rtype: str
        """
        return self._icon_class

    @icon_class.setter
    def icon_class(self, icon_class):
        """Sets the icon_class of this UserProfileField.

        the field's icon CSS class.  # noqa: E501

        :param icon_class: The icon_class of this UserProfileField.  # noqa: E501
        :type: str
        """
        if icon_class is None:
            raise ValueError(
                "Invalid value for `icon_class`, must not be `None`"
            )  # noqa: E501

        self._icon_class = icon_class

    @property
    def values(self):
        """Gets the values of this UserProfileField.  # noqa: E501

        The field's value(s).  # noqa: E501

        :return: The values of this UserProfileField.  # noqa: E501
        :rtype: list[str]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this UserProfileField.

        The field's value(s).  # noqa: E501

        :param values: The values of this UserProfileField.  # noqa: E501
        :type: list[str]
        """
        if values is None:
            raise ValueError(
                "Invalid value for `values`, must not be `None`"
            )  # noqa: E501

        self._values = values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserProfileField, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserProfileField):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from dataclasses import dataclass
from datetime import datetime

from .translation import Translations


@dataclass(frozen=True)
class Article:
    id: str
    author_id: str

    created_at: datetime

    title: Translations
    short: Translations



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Article(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "author": "UserReference",
        "created_at": "datetime",
        "updated_at": "datetime",
        "template_id": "str",
        "owner_users": "list[str]",
        "owner_groups": "list[str]",
        "shares": "list[ArticleShare]",
        "can_edit": "bool",
        "structured_content": "StructuredContent",
    }

    attribute_map = {
        "id": "id",
        "author": "author",
        "created_at": "createdAt",
        "updated_at": "updatedAt",
        "template_id": "templateId",
        "owner_users": "ownerUsers",
        "owner_groups": "ownerGroups",
        "shares": "shares",
        "can_edit": "canEdit",
        "structured_content": "structuredContent",
    }

    def __init__(
        self,
        id=None,
        author=None,
        created_at=None,
        updated_at=None,
        template_id=None,
        owner_users=None,
        owner_groups=None,
        shares=None,
        can_edit=None,
        structured_content=None,
    ):  # noqa: E501
        """Article - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._author = None
        self._created_at = None
        self._updated_at = None
        self._template_id = None
        self._owner_users = None
        self._owner_groups = None
        self._shares = None
        self._can_edit = None
        self._structured_content = None
        self.discriminator = None
        self.id = id
        if author is not None:
            self.author = author
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if template_id is not None:
            self.template_id = template_id
        if owner_users is not None:
            self.owner_users = owner_users
        if owner_groups is not None:
            self.owner_groups = owner_groups
        if shares is not None:
            self.shares = shares
        if can_edit is not None:
            self.can_edit = can_edit
        if structured_content is not None:
            self.structured_content = structured_content

    @property
    def id(self):
        """Gets the id of this Article.  # noqa: E501

        The article id  # noqa: E501

        :return: The id of this Article.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Article.

        The article id  # noqa: E501

        :param id: The id of this Article.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def author(self):
        """Gets the author of this Article.  # noqa: E501


        :return: The author of this Article.  # noqa: E501
        :rtype: UserReference
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this Article.


        :param author: The author of this Article.  # noqa: E501
        :type: UserReference
        """

        self._author = author

    @property
    def created_at(self):
        """Gets the created_at of this Article.  # noqa: E501

        The date and time when the article was created  # noqa: E501

        :return: The created_at of this Article.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Article.

        The date and time when the article was created  # noqa: E501

        :param created_at: The created_at of this Article.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this Article.  # noqa: E501

        The date and time when the article was last updated  # noqa: E501

        :return: The updated_at of this Article.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Article.

        The date and time when the article was last updated  # noqa: E501

        :param updated_at: The updated_at of this Article.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def template_id(self):
        """Gets the template_id of this Article.  # noqa: E501

        The id of the template used to display the article  # noqa: E501

        :return: The template_id of this Article.  # noqa: E501
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this Article.

        The id of the template used to display the article  # noqa: E501

        :param template_id: The template_id of this Article.  # noqa: E501
        :type: str
        """

        self._template_id = template_id

    @property
    def owner_users(self):
        """Gets the owner_users of this Article.  # noqa: E501

        The ids of users owning the article  # noqa: E501

        :return: The owner_users of this Article.  # noqa: E501
        :rtype: list[str]
        """
        return self._owner_users

    @owner_users.setter
    def owner_users(self, owner_users):
        """Sets the owner_users of this Article.

        The ids of users owning the article  # noqa: E501

        :param owner_users: The owner_users of this Article.  # noqa: E501
        :type: list[str]
        """

        self._owner_users = owner_users

    @property
    def owner_groups(self):
        """Gets the owner_groups of this Article.  # noqa: E501

        The ids of groups owning the article  # noqa: E501

        :return: The owner_groups of this Article.  # noqa: E501
        :rtype: list[str]
        """
        return self._owner_groups

    @owner_groups.setter
    def owner_groups(self, owner_groups):
        """Sets the owner_groups of this Article.

        The ids of groups owning the article  # noqa: E501

        :param owner_groups: The owner_groups of this Article.  # noqa: E501
        :type: list[str]
        """

        self._owner_groups = owner_groups

    @property
    def shares(self):
        """Gets the shares of this Article.  # noqa: E501


        :return: The shares of this Article.  # noqa: E501
        :rtype: list[ArticleShare]
        """
        return self._shares

    @shares.setter
    def shares(self, shares):
        """Sets the shares of this Article.


        :param shares: The shares of this Article.  # noqa: E501
        :type: list[ArticleShare]
        """

        self._shares = shares

    @property
    def can_edit(self):
        """Gets the can_edit of this Article.  # noqa: E501

        Whether the user doing the request can edit the article  # noqa: E501

        :return: The can_edit of this Article.  # noqa: E501
        :rtype: bool
        """
        return self._can_edit

    @can_edit.setter
    def can_edit(self, can_edit):
        """Sets the can_edit of this Article.

        Whether the user doing the request can edit the article  # noqa: E501

        :param can_edit: The can_edit of this Article.  # noqa: E501
        :type: bool
        """

        self._can_edit = can_edit

    @property
    def structured_content(self):
        """Gets the structured_content of this Article.  # noqa: E501


        :return: The structured_content of this Article.  # noqa: E501
        :rtype: StructuredContent
        """
        return self._structured_content

    @structured_content.setter
    def structured_content(self, structured_content):
        """Sets the structured_content of this Article.


        :param structured_content: The structured_content of this Article.  # noqa: E501
        :type: StructuredContent
        """

        self._structured_content = structured_content

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(Article, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Article):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from httpx import HTTPStatusError


def get_http_err_content(e: HTTPStatusError) -> str:
    try:
        return e.response.content.decode()  # type: ignore
    except AttributeError:
        return ""


class BaseClientError(Exception):  # pragma: no cover
    """Base error of the BaseClient"""


class BadCallError(BaseClientError):  # pragma: no cover
    """Retrocompatiblity"""


class LumAppsClientError(BaseClientError):  # pragma: no cover
    def __init__(self, code, message=None):
        super().__init__(message)
        self.code = code


class LumAppsClientConfError(BaseClientError):  # pragma: no cover
    def __init__(self, message=None):
        super().__init__(message)


class MissingMetadataError(LumAppsClientError):  # pragma: no cover
    def __init__(self, message):
        super().__init__("MISSING_METADATA", message)


class FileUploadError(LumAppsClientError):  # pragma: no cover
    def __init__(self, message):
        super().__init__("FILE_UPLOAD", message)


class FolderCreationError(LumAppsClientError):  # pragma: no cover
    def __init__(self, message):
        super().__init__("FILE_UPLOAD", message)


class FileDownloadError(LumAppsClientError):  # pragma: no cover
    def __init__(self, message):
        super().__init__("FILE_DOWNLOAD", message)


class NonIdpGroupInCommunityError(LumAppsClientError):  # pragma: no cover
    def __init__(self, message):
        super().__init__("NON_IDP_GROUP_IN_COMMUNITY", message)


class FeedsRequiredError(LumAppsClientError):  # pragma: no cover
    def __init__(self, message):
        super().__init__("FEEDS_REQUIRED", message)


class UrlAlreadyExistsError(LumAppsClientError):  # pragma: no cover
    def __init__(self, message):
        super().__init__("URL_ALREADY_EXISTS", message)


class GetTokenError(LumAppsClientError):  # pragma: no cover
    def __init__(self, message):
        super().__init__("GET_TOKEN", message)


class UserCannotSaveError(LumAppsClientError):  # pragma: no cover
    def __init__(self, message):
        super().__init__("USER_CANNOT_SAVE", message)


class LumAppsError(Exception):  # pragma: no cover
    pass


##
#  Jwt Errors
##


class LumAppsJWTError(LumAppsError):  # pragma: no cover
    pass


class LumAppsJWTClaimsError(LumAppsJWTError):  # pragma: no cover
    pass


class LumAppsJwtTokenExpiredError(LumAppsJWTError):  # pragma: no cover
    def __init__(self, message):
        super().__init__("TOKEN_EXPIRED", message)


class LumAppsJwtInvalidClaimError(LumAppsJWTError):  # pragma: no cover
    def __init__(self, message):
        super().__init__("INVALID_CLAIMS", message)


class LumAppsJwtCustomError(LumAppsJWTError):  # pragma: no cover
    def __init__(self, message):
        super().__init__("CUSTOM_ERROR", message)


class LumAppsJwtHeaderError(LumAppsJWTError):  # pragma: no cover
    def __init__(self, message):
        super().__init__("INVALID_HEADER", message)



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CommunityInfo(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "community_id": "str",
        "name": "str",
        "slug": "str",
        "has_secure_storage": "bool",
        "storage_doc_path": "str",
    }

    attribute_map = {
        "community_id": "communityId",
        "name": "name",
        "slug": "slug",
        "has_secure_storage": "hasSecureStorage",
        "storage_doc_path": "storageDocPath",
    }

    def __init__(
        self,
        community_id=None,
        name=None,
        slug=None,
        has_secure_storage=None,
        storage_doc_path=None,
    ):  # noqa: E501
        """CommunityInfo - a model defined in Swagger"""  # noqa: E501
        self._community_id = None
        self._name = None
        self._slug = None
        self._has_secure_storage = None
        self._storage_doc_path = None
        self.discriminator = None
        self.community_id = community_id
        self.name = name
        self.slug = slug
        self.has_secure_storage = has_secure_storage
        if storage_doc_path is not None:
            self.storage_doc_path = storage_doc_path

    @property
    def community_id(self):
        """Gets the community_id of this CommunityInfo.  # noqa: E501

        The community's id.  # noqa: E501

        :return: The community_id of this CommunityInfo.  # noqa: E501
        :rtype: str
        """
        return self._community_id

    @community_id.setter
    def community_id(self, community_id):
        """Sets the community_id of this CommunityInfo.

        The community's id.  # noqa: E501

        :param community_id: The community_id of this CommunityInfo.  # noqa: E501
        :type: str
        """
        if community_id is None:
            raise ValueError(
                "Invalid value for `community_id`, must not be `None`"
            )  # noqa: E501

        self._community_id = community_id

    @property
    def name(self):
        """Gets the name of this CommunityInfo.  # noqa: E501

        The community's name.  # noqa: E501

        :return: The name of this CommunityInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CommunityInfo.

        The community's name.  # noqa: E501

        :param name: The name of this CommunityInfo.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError(
                "Invalid value for `name`, must not be `None`"
            )  # noqa: E501

        self._name = name

    @property
    def slug(self):
        """Gets the slug of this CommunityInfo.  # noqa: E501

        The community's slug.  # noqa: E501

        :return: The slug of this CommunityInfo.  # noqa: E501
        :rtype: str
        """
        return self._slug

    @slug.setter
    def slug(self, slug):
        """Sets the slug of this CommunityInfo.

        The community's slug.  # noqa: E501

        :param slug: The slug of this CommunityInfo.  # noqa: E501
        :type: str
        """
        if slug is None:
            raise ValueError(
                "Invalid value for `slug`, must not be `None`"
            )  # noqa: E501

        self._slug = slug

    @property
    def has_secure_storage(self):
        """Gets the has_secure_storage of this CommunityInfo.  # noqa: E501

        Whether the community uses secured storage.  # noqa: E501

        :return: The has_secure_storage of this CommunityInfo.  # noqa: E501
        :rtype: bool
        """
        return self._has_secure_storage

    @has_secure_storage.setter
    def has_secure_storage(self, has_secure_storage):
        """Sets the has_secure_storage of this CommunityInfo.

        Whether the community uses secured storage.  # noqa: E501

        :param has_secure_storage: The has_secure_storage of this CommunityInfo.  # noqa: E501
        :type: bool
        """
        if has_secure_storage is None:
            raise ValueError(
                "Invalid value for `has_secure_storage`, must not be `None`"
            )  # noqa: E501

        self._has_secure_storage = has_secure_storage

    @property
    def storage_doc_path(self):
        """Gets the storage_doc_path of this CommunityInfo.  # noqa: E501

        The docpath identifying the community's storage container, if any.  # noqa: E501

        :return: The storage_doc_path of this CommunityInfo.  # noqa: E501
        :rtype: str
        """
        return self._storage_doc_path

    @storage_doc_path.setter
    def storage_doc_path(self, storage_doc_path):
        """Sets the storage_doc_path of this CommunityInfo.

        The docpath identifying the community's storage container, if any.  # noqa: E501

        :param storage_doc_path: The storage_doc_path of this CommunityInfo.  # noqa: E501
        :type: str
        """

        self._storage_doc_path = storage_doc_path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(CommunityInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CommunityInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class CreateEventInContainerRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "dita": "MultilangObject",
        "template_id": "str",
        "container": "ContainerReference",
        "starts_at": "datetime",
        "ends_at": "datetime",
        "organizers": "OrganizerIds",
        "location": "str",
        "external_url": "str",
        "external_url_label": "OneOfCreateEventInContainerRequestExternalUrlLabel",
    }

    attribute_map = {
        "dita": "dita",
        "template_id": "templateId",
        "container": "container",
        "starts_at": "startsAt",
        "ends_at": "endsAt",
        "organizers": "organizers",
        "location": "location",
        "external_url": "externalUrl",
        "external_url_label": "externalUrlLabel",
    }

    def __init__(
        self,
        dita=None,
        template_id=None,
        container=None,
        starts_at=None,
        ends_at=None,
        organizers=None,
        location=None,
        external_url=None,
        external_url_label=None,
    ):  # noqa: E501
        """CreateEventInContainerRequest - a model defined in Swagger"""  # noqa: E501
        self._dita = None
        self._template_id = None
        self._container = None
        self._starts_at = None
        self._ends_at = None
        self._organizers = None
        self._location = None
        self._external_url = None
        self._external_url_label = None
        self.discriminator = None
        self.dita = dita
        self.template_id = template_id
        self.container = container
        self.starts_at = starts_at
        self.ends_at = ends_at
        if organizers is not None:
            self.organizers = organizers
        if location is not None:
            self.location = location
        if external_url is not None:
            self.external_url = external_url
        if external_url_label is not None:
            self.external_url_label = external_url_label

    @property
    def dita(self):
        """Gets the dita of this CreateEventInContainerRequest.  # noqa: E501


        :return: The dita of this CreateEventInContainerRequest.  # noqa: E501
        :rtype: MultilangObject
        """
        return self._dita

    @dita.setter
    def dita(self, dita):
        """Sets the dita of this CreateEventInContainerRequest.


        :param dita: The dita of this CreateEventInContainerRequest.  # noqa: E501
        :type: MultilangObject
        """
        if dita is None:
            raise ValueError(
                "Invalid value for `dita`, must not be `None`"
            )  # noqa: E501

        self._dita = dita

    @property
    def template_id(self):
        """Gets the template_id of this CreateEventInContainerRequest.  # noqa: E501

        The id of the template used to display the event  # noqa: E501

        :return: The template_id of this CreateEventInContainerRequest.  # noqa: E501
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this CreateEventInContainerRequest.

        The id of the template used to display the event  # noqa: E501

        :param template_id: The template_id of this CreateEventInContainerRequest.  # noqa: E501
        :type: str
        """
        if template_id is None:
            raise ValueError(
                "Invalid value for `template_id`, must not be `None`"
            )  # noqa: E501

        self._template_id = template_id

    @property
    def container(self):
        """Gets the container of this CreateEventInContainerRequest.  # noqa: E501


        :return: The container of this CreateEventInContainerRequest.  # noqa: E501
        :rtype: ContainerReference
        """
        return self._container

    @container.setter
    def container(self, container):
        """Sets the container of this CreateEventInContainerRequest.


        :param container: The container of this CreateEventInContainerRequest.  # noqa: E501
        :type: ContainerReference
        """
        if container is None:
            raise ValueError(
                "Invalid value for `container`, must not be `None`"
            )  # noqa: E501

        self._container = container

    @property
    def starts_at(self):
        """Gets the starts_at of this CreateEventInContainerRequest.  # noqa: E501

        The event's start date and time  # noqa: E501

        :return: The starts_at of this CreateEventInContainerRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._starts_at

    @starts_at.setter
    def starts_at(self, starts_at):
        """Sets the starts_at of this CreateEventInContainerRequest.

        The event's start date and time  # noqa: E501

        :param starts_at: The starts_at of this CreateEventInContainerRequest.  # noqa: E501
        :type: datetime
        """
        if starts_at is None:
            raise ValueError(
                "Invalid value for `starts_at`, must not be `None`"
            )  # noqa: E501

        self._starts_at = starts_at

    @property
    def ends_at(self):
        """Gets the ends_at of this CreateEventInContainerRequest.  # noqa: E501

        The event's end date and time  # noqa: E501

        :return: The ends_at of this CreateEventInContainerRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._ends_at

    @ends_at.setter
    def ends_at(self, ends_at):
        """Sets the ends_at of this CreateEventInContainerRequest.

        The event's end date and time  # noqa: E501

        :param ends_at: The ends_at of this CreateEventInContainerRequest.  # noqa: E501
        :type: datetime
        """
        if ends_at is None:
            raise ValueError(
                "Invalid value for `ends_at`, must not be `None`"
            )  # noqa: E501

        self._ends_at = ends_at

    @property
    def organizers(self):
        """Gets the organizers of this CreateEventInContainerRequest.  # noqa: E501


        :return: The organizers of this CreateEventInContainerRequest.  # noqa: E501
        :rtype: OrganizerIds
        """
        return self._organizers

    @organizers.setter
    def organizers(self, organizers):
        """Sets the organizers of this CreateEventInContainerRequest.


        :param organizers: The organizers of this CreateEventInContainerRequest.  # noqa: E501
        :type: OrganizerIds
        """

        self._organizers = organizers

    @property
    def location(self):
        """Gets the location of this CreateEventInContainerRequest.  # noqa: E501

        The event's location, e.g. Yellow Meeting Room. Not to be confused with a localization. Not translatable either.   # noqa: E501

        :return: The location of this CreateEventInContainerRequest.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this CreateEventInContainerRequest.

        The event's location, e.g. Yellow Meeting Room. Not to be confused with a localization. Not translatable either.   # noqa: E501

        :param location: The location of this CreateEventInContainerRequest.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def external_url(self):
        """Gets the external_url of this CreateEventInContainerRequest.  # noqa: E501

        The url used to access an online event  # noqa: E501

        :return: The external_url of this CreateEventInContainerRequest.  # noqa: E501
        :rtype: str
        """
        return self._external_url

    @external_url.setter
    def external_url(self, external_url):
        """Sets the external_url of this CreateEventInContainerRequest.

        The url used to access an online event  # noqa: E501

        :param external_url: The external_url of this CreateEventInContainerRequest.  # noqa: E501
        :type: str
        """

        self._external_url = external_url

    @property
    def external_url_label(self):
        """Gets the external_url_label of this CreateEventInContainerRequest.  # noqa: E501


        :return: The external_url_label of this CreateEventInContainerRequest.  # noqa: E501
        :rtype: OneOfCreateEventInContainerRequestExternalUrlLabel
        """
        return self._external_url_label

    @external_url_label.setter
    def external_url_label(self, external_url_label):
        """Sets the external_url_label of this CreateEventInContainerRequest.


        :param external_url_label: The external_url_label of this CreateEventInContainerRequest.  # noqa: E501
        :type: OneOfCreateEventInContainerRequestExternalUrlLabel
        """

        self._external_url_label = external_url_label

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(CreateEventInContainerRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateEventInContainerRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Document(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"id": "str", "url": "str", "focal_x": "float", "focal_y": "float"}

    attribute_map = {"id": "id", "url": "url", "focal_x": "focalX", "focal_y": "focalY"}

    def __init__(self, id=None, url=None, focal_x=None, focal_y=None):  # noqa: E501
        """Document - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._url = None
        self._focal_x = None
        self._focal_y = None
        self.discriminator = None
        self.id = id
        self.url = url
        if focal_x is not None:
            self.focal_x = focal_x
        if focal_y is not None:
            self.focal_y = focal_y

    @property
    def id(self):
        """Gets the id of this Document.  # noqa: E501

        The document id  # noqa: E501

        :return: The id of this Document.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Document.

        The document id  # noqa: E501

        :param id: The id of this Document.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def url(self):
        """Gets the url of this Document.  # noqa: E501

        The url to download the document  # noqa: E501

        :return: The url of this Document.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Document.

        The url to download the document  # noqa: E501

        :param url: The url of this Document.  # noqa: E501
        :type: str
        """
        if url is None:
            raise ValueError(
                "Invalid value for `url`, must not be `None`"
            )  # noqa: E501

        self._url = url

    @property
    def focal_x(self):
        """Gets the focal_x of this Document.  # noqa: E501

        The X coordinate of the focal point. Only applicable if the document is an image.  # noqa: E501

        :return: The focal_x of this Document.  # noqa: E501
        :rtype: float
        """
        return self._focal_x

    @focal_x.setter
    def focal_x(self, focal_x):
        """Sets the focal_x of this Document.

        The X coordinate of the focal point. Only applicable if the document is an image.  # noqa: E501

        :param focal_x: The focal_x of this Document.  # noqa: E501
        :type: float
        """

        self._focal_x = focal_x

    @property
    def focal_y(self):
        """Gets the focal_y of this Document.  # noqa: E501

        The Y coordinate of the focal point. Only applicable if the document is an image.  # noqa: E501

        :return: The focal_y of this Document.  # noqa: E501
        :rtype: float
        """
        return self._focal_y

    @focal_y.setter
    def focal_y(self, focal_y):
        """Sets the focal_y of this Document.

        The Y coordinate of the focal point. Only applicable if the document is an image.  # noqa: E501

        :param focal_y: The focal_y of this Document.  # noqa: E501
        :type: float
        """

        self._focal_y = focal_y

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(Document, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Document):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from .base_block import BaseBlock  # noqa: F401,E501


class BlockInappropriate(BaseBlock):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "report_count": "int",
        "last_reported_at": "datetime",
        "is_reported_by_me": "bool",
    }
    if hasattr(BaseBlock, "swagger_types"):
        swagger_types.update(BaseBlock.swagger_types)

    attribute_map = {
        "report_count": "reportCount",
        "last_reported_at": "lastReportedAt",
        "is_reported_by_me": "isReportedByMe",
    }
    if hasattr(BaseBlock, "attribute_map"):
        attribute_map.update(BaseBlock.attribute_map)

    def __init__(
        self,
        report_count=None,
        last_reported_at=None,
        is_reported_by_me=None,
        *args,
        **kwargs
    ):  # noqa: E501
        """BlockInappropriate - a model defined in Swagger"""  # noqa: E501
        self._report_count = None
        self._last_reported_at = None
        self._is_reported_by_me = None
        self.discriminator = None
        self.report_count = report_count
        self.last_reported_at = last_reported_at
        self.is_reported_by_me = is_reported_by_me
        BaseBlock.__init__(self, *args, **kwargs)

    @property
    def report_count(self):
        """Gets the report_count of this BlockInappropriate.  # noqa: E501

        The number of reports received for the associated resource.  # noqa: E501

        :return: The report_count of this BlockInappropriate.  # noqa: E501
        :rtype: int
        """
        return self._report_count

    @report_count.setter
    def report_count(self, report_count):
        """Sets the report_count of this BlockInappropriate.

        The number of reports received for the associated resource.  # noqa: E501

        :param report_count: The report_count of this BlockInappropriate.  # noqa: E501
        :type: int
        """
        if report_count is None:
            raise ValueError(
                "Invalid value for `report_count`, must not be `None`"
            )  # noqa: E501

        self._report_count = report_count

    @property
    def last_reported_at(self):
        """Gets the last_reported_at of this BlockInappropriate.  # noqa: E501

        The date and time when the associated resource got reported.  # noqa: E501

        :return: The last_reported_at of this BlockInappropriate.  # noqa: E501
        :rtype: datetime
        """
        return self._last_reported_at

    @last_reported_at.setter
    def last_reported_at(self, last_reported_at):
        """Sets the last_reported_at of this BlockInappropriate.

        The date and time when the associated resource got reported.  # noqa: E501

        :param last_reported_at: The last_reported_at of this BlockInappropriate.  # noqa: E501
        :type: datetime
        """
        if last_reported_at is None:
            raise ValueError(
                "Invalid value for `last_reported_at`, must not be `None`"
            )  # noqa: E501

        self._last_reported_at = last_reported_at

    @property
    def is_reported_by_me(self):
        """Gets the is_reported_by_me of this BlockInappropriate.  # noqa: E501

        Whether the current user has reported the assicated resource.  # noqa: E501

        :return: The is_reported_by_me of this BlockInappropriate.  # noqa: E501
        :rtype: bool
        """
        return self._is_reported_by_me

    @is_reported_by_me.setter
    def is_reported_by_me(self, is_reported_by_me):
        """Sets the is_reported_by_me of this BlockInappropriate.

        Whether the current user has reported the assicated resource.  # noqa: E501

        :param is_reported_by_me: The is_reported_by_me of this BlockInappropriate.  # noqa: E501
        :type: bool
        """
        if is_reported_by_me is None:
            raise ValueError(
                "Invalid value for `is_reported_by_me`, must not be `None`"
            )  # noqa: E501

        self._is_reported_by_me = is_reported_by_me

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(BlockInappropriate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockInappropriate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from .base_block import BaseBlock  # noqa: F401,E501


class BlockSlideshow(BaseBlock):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "variant": "SlideshowVariant",
        "is_autoplay_enabled": "bool",
        "autoplay_delay": "int",
        "is_navigation_visible": "bool",
        "visible_items": "int",
        "items": "list[object]",
    }
    if hasattr(BaseBlock, "swagger_types"):
        swagger_types.update(BaseBlock.swagger_types)

    attribute_map = {
        "variant": "variant",
        "is_autoplay_enabled": "isAutoplayEnabled",
        "autoplay_delay": "autoplayDelay",
        "is_navigation_visible": "isNavigationVisible",
        "visible_items": "visibleItems",
        "items": "items",
    }
    if hasattr(BaseBlock, "attribute_map"):
        attribute_map.update(BaseBlock.attribute_map)

    def __init__(
        self,
        variant=None,
        is_autoplay_enabled=None,
        autoplay_delay=None,
        is_navigation_visible=None,
        visible_items=None,
        items=None,
        *args,
        **kwargs
    ):  # noqa: E501
        """BlockSlideshow - a model defined in Swagger"""  # noqa: E501
        self._variant = None
        self._is_autoplay_enabled = None
        self._autoplay_delay = None
        self._is_navigation_visible = None
        self._visible_items = None
        self._items = None
        self.discriminator = None
        self.variant = variant
        self.is_autoplay_enabled = is_autoplay_enabled
        if autoplay_delay is not None:
            self.autoplay_delay = autoplay_delay
        self.is_navigation_visible = is_navigation_visible
        if visible_items is not None:
            self.visible_items = visible_items
        self.items = items
        BaseBlock.__init__(self, *args, **kwargs)

    @property
    def variant(self):
        """Gets the variant of this BlockSlideshow.  # noqa: E501


        :return: The variant of this BlockSlideshow.  # noqa: E501
        :rtype: SlideshowVariant
        """
        return self._variant

    @variant.setter
    def variant(self, variant):
        """Sets the variant of this BlockSlideshow.


        :param variant: The variant of this BlockSlideshow.  # noqa: E501
        :type: SlideshowVariant
        """
        if variant is None:
            raise ValueError(
                "Invalid value for `variant`, must not be `None`"
            )  # noqa: E501

        self._variant = variant

    @property
    def is_autoplay_enabled(self):
        """Gets the is_autoplay_enabled of this BlockSlideshow.  # noqa: E501

        Whether the slideshow should play automatically.  # noqa: E501

        :return: The is_autoplay_enabled of this BlockSlideshow.  # noqa: E501
        :rtype: bool
        """
        return self._is_autoplay_enabled

    @is_autoplay_enabled.setter
    def is_autoplay_enabled(self, is_autoplay_enabled):
        """Sets the is_autoplay_enabled of this BlockSlideshow.

        Whether the slideshow should play automatically.  # noqa: E501

        :param is_autoplay_enabled: The is_autoplay_enabled of this BlockSlideshow.  # noqa: E501
        :type: bool
        """
        if is_autoplay_enabled is None:
            raise ValueError(
                "Invalid value for `is_autoplay_enabled`, must not be `None`"
            )  # noqa: E501

        self._is_autoplay_enabled = is_autoplay_enabled

    @property
    def autoplay_delay(self):
        """Gets the autoplay_delay of this BlockSlideshow.  # noqa: E501

        The delay in seconds before navigating automatically to the next page.  # noqa: E501

        :return: The autoplay_delay of this BlockSlideshow.  # noqa: E501
        :rtype: int
        """
        return self._autoplay_delay

    @autoplay_delay.setter
    def autoplay_delay(self, autoplay_delay):
        """Sets the autoplay_delay of this BlockSlideshow.

        The delay in seconds before navigating automatically to the next page.  # noqa: E501

        :param autoplay_delay: The autoplay_delay of this BlockSlideshow.  # noqa: E501
        :type: int
        """

        self._autoplay_delay = autoplay_delay

    @property
    def is_navigation_visible(self):
        """Gets the is_navigation_visible of this BlockSlideshow.  # noqa: E501

        Whether navigation controls should be displayed.  # noqa: E501

        :return: The is_navigation_visible of this BlockSlideshow.  # noqa: E501
        :rtype: bool
        """
        return self._is_navigation_visible

    @is_navigation_visible.setter
    def is_navigation_visible(self, is_navigation_visible):
        """Sets the is_navigation_visible of this BlockSlideshow.

        Whether navigation controls should be displayed.  # noqa: E501

        :param is_navigation_visible: The is_navigation_visible of this BlockSlideshow.  # noqa: E501
        :type: bool
        """
        if is_navigation_visible is None:
            raise ValueError(
                "Invalid value for `is_navigation_visible`, must not be `None`"
            )  # noqa: E501

        self._is_navigation_visible = is_navigation_visible

    @property
    def visible_items(self):
        """Gets the visible_items of this BlockSlideshow.  # noqa: E501

        The number of items that should be visible at any one time.  # noqa: E501

        :return: The visible_items of this BlockSlideshow.  # noqa: E501
        :rtype: int
        """
        return self._visible_items

    @visible_items.setter
    def visible_items(self, visible_items):
        """Sets the visible_items of this BlockSlideshow.

        The number of items that should be visible at any one time.  # noqa: E501

        :param visible_items: The visible_items of this BlockSlideshow.  # noqa: E501
        :type: int
        """

        self._visible_items = visible_items

    @property
    def items(self):
        """Gets the items of this BlockSlideshow.  # noqa: E501

        The slideshow's items.  # noqa: E501

        :return: The items of this BlockSlideshow.  # noqa: E501
        :rtype: list[object]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this BlockSlideshow.

        The slideshow's items.  # noqa: E501

        :param items: The items of this BlockSlideshow.  # noqa: E501
        :type: list[object]
        """
        if items is None:
            raise ValueError(
                "Invalid value for `items`, must not be `None`"
            )  # noqa: E501

        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(BlockSlideshow, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockSlideshow):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from lumapps.latest.client import IClient
from lumapps.latest.entities.article import Article

from .swagger.contribution_v1 import ContributionV1GW


class ArticleApi:
    def __init__(self, client: IClient) -> None:
        self.gateway = ContributionV1GW(client)

    def get_article(self, article_id: str) -> Article:
        model = self.gateway.get_article(article_id)
        return Article(
            model.id,
            model.author.user_id,
            model.created_at,
            model.structured_content.title.translations,
            model.structured_content.intro.translations,
        )



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from .base_block import BaseBlock  # noqa: F401,E501


class BlockImage(BaseBlock):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "url": "str",
        "focal_x": "float",
        "focal_y": "float",
        "crop_x": "int",
        "crop_y": "int",
        "height": "int",
        "width": "int",
        "scale_x": "float",
        "scale_y": "float",
        "rotate": "float",
        "fit": "str",
        "cover_ratio": "str",
        "corner_variant": "str",
    }
    if hasattr(BaseBlock, "swagger_types"):
        swagger_types.update(BaseBlock.swagger_types)

    attribute_map = {
        "url": "url",
        "focal_x": "focalX",
        "focal_y": "focalY",
        "crop_x": "cropX",
        "crop_y": "cropY",
        "height": "height",
        "width": "width",
        "scale_x": "scaleX",
        "scale_y": "scaleY",
        "rotate": "rotate",
        "fit": "fit",
        "cover_ratio": "coverRatio",
        "corner_variant": "cornerVariant",
    }
    if hasattr(BaseBlock, "attribute_map"):
        attribute_map.update(BaseBlock.attribute_map)

    def __init__(
        self,
        url=None,
        focal_x=None,
        focal_y=None,
        crop_x=None,
        crop_y=None,
        height=None,
        width=None,
        scale_x=None,
        scale_y=None,
        rotate=None,
        fit=None,
        cover_ratio=None,
        corner_variant=None,
        *args,
        **kwargs
    ):  # noqa: E501
        """BlockImage - a model defined in Swagger"""  # noqa: E501
        self._url = None
        self._focal_x = None
        self._focal_y = None
        self._crop_x = None
        self._crop_y = None
        self._height = None
        self._width = None
        self._scale_x = None
        self._scale_y = None
        self._rotate = None
        self._fit = None
        self._cover_ratio = None
        self._corner_variant = None
        self.discriminator = None
        self.url = url
        if focal_x is not None:
            self.focal_x = focal_x
        if focal_y is not None:
            self.focal_y = focal_y
        if crop_x is not None:
            self.crop_x = crop_x
        if crop_y is not None:
            self.crop_y = crop_y
        if height is not None:
            self.height = height
        if width is not None:
            self.width = width
        if scale_x is not None:
            self.scale_x = scale_x
        if scale_y is not None:
            self.scale_y = scale_y
        if rotate is not None:
            self.rotate = rotate
        if fit is not None:
            self.fit = fit
        if cover_ratio is not None:
            self.cover_ratio = cover_ratio
        if corner_variant is not None:
            self.corner_variant = corner_variant
        BaseBlock.__init__(self, *args, **kwargs)

    @property
    def url(self):
        """Gets the url of this BlockImage.  # noqa: E501

        The url of the image.  # noqa: E501

        :return: The url of this BlockImage.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this BlockImage.

        The url of the image.  # noqa: E501

        :param url: The url of this BlockImage.  # noqa: E501
        :type: str
        """
        if url is None:
            raise ValueError(
                "Invalid value for `url`, must not be `None`"
            )  # noqa: E501

        self._url = url

    @property
    def focal_x(self):
        """Gets the focal_x of this BlockImage.  # noqa: E501

        The X ratio of the focal point in the image.  # noqa: E501

        :return: The focal_x of this BlockImage.  # noqa: E501
        :rtype: float
        """
        return self._focal_x

    @focal_x.setter
    def focal_x(self, focal_x):
        """Sets the focal_x of this BlockImage.

        The X ratio of the focal point in the image.  # noqa: E501

        :param focal_x: The focal_x of this BlockImage.  # noqa: E501
        :type: float
        """

        self._focal_x = focal_x

    @property
    def focal_y(self):
        """Gets the focal_y of this BlockImage.  # noqa: E501

        The Y ratio of the focal point in the image.  # noqa: E501

        :return: The focal_y of this BlockImage.  # noqa: E501
        :rtype: float
        """
        return self._focal_y

    @focal_y.setter
    def focal_y(self, focal_y):
        """Sets the focal_y of this BlockImage.

        The Y ratio of the focal point in the image.  # noqa: E501

        :param focal_y: The focal_y of this BlockImage.  # noqa: E501
        :type: float
        """

        self._focal_y = focal_y

    @property
    def crop_x(self):
        """Gets the crop_x of this BlockImage.  # noqa: E501

        The X coordinate of the origin point of the cropped area (in pixels).  # noqa: E501

        :return: The crop_x of this BlockImage.  # noqa: E501
        :rtype: int
        """
        return self._crop_x

    @crop_x.setter
    def crop_x(self, crop_x):
        """Sets the crop_x of this BlockImage.

        The X coordinate of the origin point of the cropped area (in pixels).  # noqa: E501

        :param crop_x: The crop_x of this BlockImage.  # noqa: E501
        :type: int
        """

        self._crop_x = crop_x

    @property
    def crop_y(self):
        """Gets the crop_y of this BlockImage.  # noqa: E501

        The Y coordinate of the origin point of the cropped area (in pixels).  # noqa: E501

        :return: The crop_y of this BlockImage.  # noqa: E501
        :rtype: int
        """
        return self._crop_y

    @crop_y.setter
    def crop_y(self, crop_y):
        """Sets the crop_y of this BlockImage.

        The Y coordinate of the origin point of the cropped area (in pixels).  # noqa: E501

        :param crop_y: The crop_y of this BlockImage.  # noqa: E501
        :type: int
        """

        self._crop_y = crop_y

    @property
    def height(self):
        """Gets the height of this BlockImage.  # noqa: E501

        The height of the cropped area (in pixels).  # noqa: E501

        :return: The height of this BlockImage.  # noqa: E501
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        """Sets the height of this BlockImage.

        The height of the cropped area (in pixels).  # noqa: E501

        :param height: The height of this BlockImage.  # noqa: E501
        :type: int
        """

        self._height = height

    @property
    def width(self):
        """Gets the width of this BlockImage.  # noqa: E501

        The width of the cropped area (in pixels).  # noqa: E501

        :return: The width of this BlockImage.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this BlockImage.

        The width of the cropped area (in pixels).  # noqa: E501

        :param width: The width of this BlockImage.  # noqa: E501
        :type: int
        """

        self._width = width

    @property
    def scale_x(self):
        """Gets the scale_x of this BlockImage.  # noqa: E501

        The scaling along the X axis.  # noqa: E501

        :return: The scale_x of this BlockImage.  # noqa: E501
        :rtype: float
        """
        return self._scale_x

    @scale_x.setter
    def scale_x(self, scale_x):
        """Sets the scale_x of this BlockImage.

        The scaling along the X axis.  # noqa: E501

        :param scale_x: The scale_x of this BlockImage.  # noqa: E501
        :type: float
        """

        self._scale_x = scale_x

    @property
    def scale_y(self):
        """Gets the scale_y of this BlockImage.  # noqa: E501

        The scaling along the Y axis.  # noqa: E501

        :return: The scale_y of this BlockImage.  # noqa: E501
        :rtype: float
        """
        return self._scale_y

    @scale_y.setter
    def scale_y(self, scale_y):
        """Sets the scale_y of this BlockImage.

        The scaling along the Y axis.  # noqa: E501

        :param scale_y: The scale_y of this BlockImage.  # noqa: E501
        :type: float
        """

        self._scale_y = scale_y

    @property
    def rotate(self):
        """Gets the rotate of this BlockImage.  # noqa: E501

        The image rotation (in degrees).  # noqa: E501

        :return: The rotate of this BlockImage.  # noqa: E501
        :rtype: float
        """
        return self._rotate

    @rotate.setter
    def rotate(self, rotate):
        """Sets the rotate of this BlockImage.

        The image rotation (in degrees).  # noqa: E501

        :param rotate: The rotate of this BlockImage.  # noqa: E501
        :type: float
        """

        self._rotate = rotate

    @property
    def fit(self):
        """Gets the fit of this BlockImage.  # noqa: E501

        The fit to use when displaying this image.  # noqa: E501

        :return: The fit of this BlockImage.  # noqa: E501
        :rtype: str
        """
        return self._fit

    @fit.setter
    def fit(self, fit):
        """Sets the fit of this BlockImage.

        The fit to use when displaying this image.  # noqa: E501

        :param fit: The fit of this BlockImage.  # noqa: E501
        :type: str
        """
        allowed_values = ["contain", "cover"]  # noqa: E501
        if fit not in allowed_values:
            raise ValueError(
                "Invalid value for `fit` ({0}), must be one of {1}".format(  # noqa: E501
                    fit, allowed_values
                )
            )

        self._fit = fit

    @property
    def cover_ratio(self):
        """Gets the cover_ratio of this BlockImage.  # noqa: E501

        The ratio to use when displaying the image in cover mode only.  # noqa: E501

        :return: The cover_ratio of this BlockImage.  # noqa: E501
        :rtype: str
        """
        return self._cover_ratio

    @cover_ratio.setter
    def cover_ratio(self, cover_ratio):
        """Sets the cover_ratio of this BlockImage.

        The ratio to use when displaying the image in cover mode only.  # noqa: E501

        :param cover_ratio: The cover_ratio of this BlockImage.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "original",
            "horizontal",
            "vertical",
            "square",
            "free",
            "wide",
        ]  # noqa: E501
        if cover_ratio not in allowed_values:
            raise ValueError(
                "Invalid value for `cover_ratio` ({0}), must be one of {1}".format(  # noqa: E501
                    cover_ratio, allowed_values
                )
            )

        self._cover_ratio = cover_ratio

    @property
    def corner_variant(self):
        """Gets the corner_variant of this BlockImage.  # noqa: E501

        The corner type.  # noqa: E501

        :return: The corner_variant of this BlockImage.  # noqa: E501
        :rtype: str
        """
        return self._corner_variant

    @corner_variant.setter
    def corner_variant(self, corner_variant):
        """Sets the corner_variant of this BlockImage.

        The corner type.  # noqa: E501

        :param corner_variant: The corner_variant of this BlockImage.  # noqa: E501
        :type: str
        """
        allowed_values = ["squared", "rounded"]  # noqa: E501
        if corner_variant not in allowed_values:
            raise ValueError(
                "Invalid value for `corner_variant` ({0}), must be one of {1}".format(  # noqa: E501
                    corner_variant, allowed_values
                )
            )

        self._corner_variant = corner_variant

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(BlockImage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockImage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from .base_block import BaseBlock  # noqa: F401,E501


class BlockGenericResource(BaseBlock):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "title": "str",
        "description": "str",
        "image": "BlockImage",
        "variant": "str",
        "link": "str",
    }
    if hasattr(BaseBlock, "swagger_types"):
        swagger_types.update(BaseBlock.swagger_types)

    attribute_map = {
        "title": "title",
        "description": "description",
        "image": "image",
        "variant": "variant",
        "link": "link",
    }
    if hasattr(BaseBlock, "attribute_map"):
        attribute_map.update(BaseBlock.attribute_map)

    def __init__(
        self,
        title=None,
        description=None,
        image=None,
        variant=None,
        link=None,
        *args,
        **kwargs
    ):  # noqa: E501
        """BlockGenericResource - a model defined in Swagger"""  # noqa: E501
        self._title = None
        self._description = None
        self._image = None
        self._variant = None
        self._link = None
        self.discriminator = None
        self.title = title
        if description is not None:
            self.description = description
        self.image = image
        self.variant = variant
        if link is not None:
            self.link = link
        BaseBlock.__init__(self, *args, **kwargs)

    @property
    def title(self):
        """Gets the title of this BlockGenericResource.  # noqa: E501

        The resource's title.  # noqa: E501

        :return: The title of this BlockGenericResource.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this BlockGenericResource.

        The resource's title.  # noqa: E501

        :param title: The title of this BlockGenericResource.  # noqa: E501
        :type: str
        """
        if title is None:
            raise ValueError(
                "Invalid value for `title`, must not be `None`"
            )  # noqa: E501

        self._title = title

    @property
    def description(self):
        """Gets the description of this BlockGenericResource.  # noqa: E501

        The resource's description.  # noqa: E501

        :return: The description of this BlockGenericResource.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BlockGenericResource.

        The resource's description.  # noqa: E501

        :param description: The description of this BlockGenericResource.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def image(self):
        """Gets the image of this BlockGenericResource.  # noqa: E501


        :return: The image of this BlockGenericResource.  # noqa: E501
        :rtype: BlockImage
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this BlockGenericResource.


        :param image: The image of this BlockGenericResource.  # noqa: E501
        :type: BlockImage
        """
        if image is None:
            raise ValueError(
                "Invalid value for `image`, must not be `None`"
            )  # noqa: E501

        self._image = image

    @property
    def variant(self):
        """Gets the variant of this BlockGenericResource.  # noqa: E501


        :return: The variant of this BlockGenericResource.  # noqa: E501
        :rtype: str
        """
        return self._variant

    @variant.setter
    def variant(self, variant):
        """Sets the variant of this BlockGenericResource.


        :param variant: The variant of this BlockGenericResource.  # noqa: E501
        :type: str
        """
        if variant is None:
            raise ValueError(
                "Invalid value for `variant`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["VERTICAL", "HORIZONTAL"]  # noqa: E501
        if variant not in allowed_values:
            raise ValueError(
                "Invalid value for `variant` ({0}), must be one of {1}".format(  # noqa: E501
                    variant, allowed_values
                )
            )

        self._variant = variant

    @property
    def link(self):
        """Gets the link of this BlockGenericResource.  # noqa: E501

        The url to navigate to when the user interacts with the resource.  # noqa: E501

        :return: The link of this BlockGenericResource.  # noqa: E501
        :rtype: str
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this BlockGenericResource.

        The url to navigate to when the user interacts with the resource.  # noqa: E501

        :param link: The link of this BlockGenericResource.  # noqa: E501
        :type: str
        """

        self._link = link

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(BlockGenericResource, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockGenericResource):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class EventLinkLabel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"type": "str", "value": "str", "icon": "str"}

    attribute_map = {"type": "type", "value": "value", "icon": "icon"}

    def __init__(self, type=None, value=None, icon=None):  # noqa: E501
        """EventLinkLabel - a model defined in Swagger"""  # noqa: E501
        self._type = None
        self._value = None
        self._icon = None
        self.discriminator = None
        self.type = type
        if value is not None:
            self.value = value
        if icon is not None:
            self.icon = icon

    @property
    def type(self):
        """Gets the type of this EventLinkLabel.  # noqa: E501

        The type of label. The default type is original-link. Some static types are defined and allow the client to display static labels and icons. When the link label is of type custom, it means that the client must use the value and icon returned by the API to display the link.   # noqa: E501

        :return: The type of this EventLinkLabel.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this EventLinkLabel.

        The type of label. The default type is original-link. Some static types are defined and allow the client to display static labels and icons. When the link label is of type custom, it means that the client must use the value and icon returned by the API to display the link.   # noqa: E501

        :param type: The type of this EventLinkLabel.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError(
                "Invalid value for `type`, must not be `None`"
            )  # noqa: E501
        allowed_values = [
            "custom",
            "registration",
            "videoconference",
            "recording",
            "original-link",
        ]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}".format(  # noqa: E501
                    type, allowed_values
                )
            )

        self._type = type

    @property
    def value(self):
        """Gets the value of this EventLinkLabel.  # noqa: E501

        The custom value of the link label to display.  # noqa: E501

        :return: The value of this EventLinkLabel.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this EventLinkLabel.

        The custom value of the link label to display.  # noqa: E501

        :param value: The value of this EventLinkLabel.  # noqa: E501
        :type: str
        """

        self._value = value

    @property
    def icon(self):
        """Gets the icon of this EventLinkLabel.  # noqa: E501

        The custom icon of the link label.  # noqa: E501

        :return: The icon of this EventLinkLabel.  # noqa: E501
        :rtype: str
        """
        return self._icon

    @icon.setter
    def icon(self, icon):
        """Sets the icon of this EventLinkLabel.

        The custom icon of the link label.  # noqa: E501

        :param icon: The icon of this EventLinkLabel.  # noqa: E501
        :type: str
        """

        self._icon = icon

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(EventLinkLabel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EventLinkLabel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from .base_block import BaseBlock  # noqa: F401,E501


class BlockDirectoryEntry(BaseBlock):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "directory_entry_id": "str",
        "directory_id": "str",
        "title": "str",
        "tags": "BlockTagReferenceList",
        "link": "str",
        "image": "BlockImage",
        "variant": "str",
        "is_favorite": "bool",
        "is_favorite_icon_visible": "bool",
        "metadata": "list[MetadataReference]",
    }
    if hasattr(BaseBlock, "swagger_types"):
        swagger_types.update(BaseBlock.swagger_types)

    attribute_map = {
        "directory_entry_id": "directoryEntryId",
        "directory_id": "directoryId",
        "title": "title",
        "tags": "tags",
        "link": "link",
        "image": "image",
        "variant": "variant",
        "is_favorite": "isFavorite",
        "is_favorite_icon_visible": "isFavoriteIconVisible",
        "metadata": "metadata",
    }
    if hasattr(BaseBlock, "attribute_map"):
        attribute_map.update(BaseBlock.attribute_map)

    def __init__(
        self,
        directory_entry_id=None,
        directory_id=None,
        title=None,
        tags=None,
        link=None,
        image=None,
        variant=None,
        is_favorite=None,
        is_favorite_icon_visible=None,
        metadata=None,
        *args,
        **kwargs
    ):  # noqa: E501
        """BlockDirectoryEntry - a model defined in Swagger"""  # noqa: E501
        self._directory_entry_id = None
        self._directory_id = None
        self._title = None
        self._tags = None
        self._link = None
        self._image = None
        self._variant = None
        self._is_favorite = None
        self._is_favorite_icon_visible = None
        self._metadata = None
        self.discriminator = None
        self.directory_entry_id = directory_entry_id
        self.directory_id = directory_id
        if title is not None:
            self.title = title
        if tags is not None:
            self.tags = tags
        self.link = link
        if image is not None:
            self.image = image
        self.variant = variant
        self.is_favorite = is_favorite
        self.is_favorite_icon_visible = is_favorite_icon_visible
        if metadata is not None:
            self.metadata = metadata
        BaseBlock.__init__(self, *args, **kwargs)

    @property
    def directory_entry_id(self):
        """Gets the directory_entry_id of this BlockDirectoryEntry.  # noqa: E501

        The entry's id.  # noqa: E501

        :return: The directory_entry_id of this BlockDirectoryEntry.  # noqa: E501
        :rtype: str
        """
        return self._directory_entry_id

    @directory_entry_id.setter
    def directory_entry_id(self, directory_entry_id):
        """Sets the directory_entry_id of this BlockDirectoryEntry.

        The entry's id.  # noqa: E501

        :param directory_entry_id: The directory_entry_id of this BlockDirectoryEntry.  # noqa: E501
        :type: str
        """
        if directory_entry_id is None:
            raise ValueError(
                "Invalid value for `directory_entry_id`, must not be `None`"
            )  # noqa: E501

        self._directory_entry_id = directory_entry_id

    @property
    def directory_id(self):
        """Gets the directory_id of this BlockDirectoryEntry.  # noqa: E501

        The id of the directory to which this entry belongs.  # noqa: E501

        :return: The directory_id of this BlockDirectoryEntry.  # noqa: E501
        :rtype: str
        """
        return self._directory_id

    @directory_id.setter
    def directory_id(self, directory_id):
        """Sets the directory_id of this BlockDirectoryEntry.

        The id of the directory to which this entry belongs.  # noqa: E501

        :param directory_id: The directory_id of this BlockDirectoryEntry.  # noqa: E501
        :type: str
        """
        if directory_id is None:
            raise ValueError(
                "Invalid value for `directory_id`, must not be `None`"
            )  # noqa: E501

        self._directory_id = directory_id

    @property
    def title(self):
        """Gets the title of this BlockDirectoryEntry.  # noqa: E501

        The entry's title.  # noqa: E501

        :return: The title of this BlockDirectoryEntry.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this BlockDirectoryEntry.

        The entry's title.  # noqa: E501

        :param title: The title of this BlockDirectoryEntry.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def tags(self):
        """Gets the tags of this BlockDirectoryEntry.  # noqa: E501


        :return: The tags of this BlockDirectoryEntry.  # noqa: E501
        :rtype: BlockTagReferenceList
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this BlockDirectoryEntry.


        :param tags: The tags of this BlockDirectoryEntry.  # noqa: E501
        :type: BlockTagReferenceList
        """

        self._tags = tags

    @property
    def link(self):
        """Gets the link of this BlockDirectoryEntry.  # noqa: E501

        The entry's url.  # noqa: E501

        :return: The link of this BlockDirectoryEntry.  # noqa: E501
        :rtype: str
        """
        return self._link

    @link.setter
    def link(self, link):
        """Sets the link of this BlockDirectoryEntry.

        The entry's url.  # noqa: E501

        :param link: The link of this BlockDirectoryEntry.  # noqa: E501
        :type: str
        """
        if link is None:
            raise ValueError(
                "Invalid value for `link`, must not be `None`"
            )  # noqa: E501

        self._link = link

    @property
    def image(self):
        """Gets the image of this BlockDirectoryEntry.  # noqa: E501


        :return: The image of this BlockDirectoryEntry.  # noqa: E501
        :rtype: BlockImage
        """
        return self._image

    @image.setter
    def image(self, image):
        """Sets the image of this BlockDirectoryEntry.


        :param image: The image of this BlockDirectoryEntry.  # noqa: E501
        :type: BlockImage
        """

        self._image = image

    @property
    def variant(self):
        """Gets the variant of this BlockDirectoryEntry.  # noqa: E501


        :return: The variant of this BlockDirectoryEntry.  # noqa: E501
        :rtype: str
        """
        return self._variant

    @variant.setter
    def variant(self, variant):
        """Sets the variant of this BlockDirectoryEntry.


        :param variant: The variant of this BlockDirectoryEntry.  # noqa: E501
        :type: str
        """
        if variant is None:
            raise ValueError(
                "Invalid value for `variant`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["VERTICAL", "HORIZONTAL"]  # noqa: E501
        if variant not in allowed_values:
            raise ValueError(
                "Invalid value for `variant` ({0}), must be one of {1}".format(  # noqa: E501
                    variant, allowed_values
                )
            )

        self._variant = variant

    @property
    def is_favorite(self):
        """Gets the is_favorite of this BlockDirectoryEntry.  # noqa: E501

        Whether the current user has added the entry to his favorites.  # noqa: E501

        :return: The is_favorite of this BlockDirectoryEntry.  # noqa: E501
        :rtype: bool
        """
        return self._is_favorite

    @is_favorite.setter
    def is_favorite(self, is_favorite):
        """Sets the is_favorite of this BlockDirectoryEntry.

        Whether the current user has added the entry to his favorites.  # noqa: E501

        :param is_favorite: The is_favorite of this BlockDirectoryEntry.  # noqa: E501
        :type: bool
        """
        if is_favorite is None:
            raise ValueError(
                "Invalid value for `is_favorite`, must not be `None`"
            )  # noqa: E501

        self._is_favorite = is_favorite

    @property
    def is_favorite_icon_visible(self):
        """Gets the is_favorite_icon_visible of this BlockDirectoryEntry.  # noqa: E501

        Whether the favorite icon is visible.  # noqa: E501

        :return: The is_favorite_icon_visible of this BlockDirectoryEntry.  # noqa: E501
        :rtype: bool
        """
        return self._is_favorite_icon_visible

    @is_favorite_icon_visible.setter
    def is_favorite_icon_visible(self, is_favorite_icon_visible):
        """Sets the is_favorite_icon_visible of this BlockDirectoryEntry.

        Whether the favorite icon is visible.  # noqa: E501

        :param is_favorite_icon_visible: The is_favorite_icon_visible of this BlockDirectoryEntry.  # noqa: E501
        :type: bool
        """
        if is_favorite_icon_visible is None:
            raise ValueError(
                "Invalid value for `is_favorite_icon_visible`, must not be `None`"
            )  # noqa: E501

        self._is_favorite_icon_visible = is_favorite_icon_visible

    @property
    def metadata(self):
        """Gets the metadata of this BlockDirectoryEntry.  # noqa: E501


        :return: The metadata of this BlockDirectoryEntry.  # noqa: E501
        :rtype: list[MetadataReference]
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this BlockDirectoryEntry.


        :param metadata: The metadata of this BlockDirectoryEntry.  # noqa: E501
        :type: list[MetadataReference]
        """

        self._metadata = metadata

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(BlockDirectoryEntry, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockDirectoryEntry):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class MediaPreview(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "media_id": "str",
        "title": "str",
        "description": "str",
        "file_name": "str",
        "url": "str",
        "mime_type": "str",
        "is_secure": "bool",
        "thumbnail": "BlockImage",
    }

    attribute_map = {
        "media_id": "mediaId",
        "title": "title",
        "description": "description",
        "file_name": "fileName",
        "url": "url",
        "mime_type": "mimeType",
        "is_secure": "isSecure",
        "thumbnail": "thumbnail",
    }

    def __init__(
        self,
        media_id=None,
        title=None,
        description=None,
        file_name=None,
        url=None,
        mime_type=None,
        is_secure=None,
        thumbnail=None,
    ):  # noqa: E501
        """MediaPreview - a model defined in Swagger"""  # noqa: E501
        self._media_id = None
        self._title = None
        self._description = None
        self._file_name = None
        self._url = None
        self._mime_type = None
        self._is_secure = None
        self._thumbnail = None
        self.discriminator = None
        if media_id is not None:
            self.media_id = media_id
        self.title = title
        if description is not None:
            self.description = description
        self.file_name = file_name
        self.url = url
        self.mime_type = mime_type
        self.is_secure = is_secure
        if thumbnail is not None:
            self.thumbnail = thumbnail

    @property
    def media_id(self):
        """Gets the media_id of this MediaPreview.  # noqa: E501

        The media's id.  # noqa: E501

        :return: The media_id of this MediaPreview.  # noqa: E501
        :rtype: str
        """
        return self._media_id

    @media_id.setter
    def media_id(self, media_id):
        """Sets the media_id of this MediaPreview.

        The media's id.  # noqa: E501

        :param media_id: The media_id of this MediaPreview.  # noqa: E501
        :type: str
        """

        self._media_id = media_id

    @property
    def title(self):
        """Gets the title of this MediaPreview.  # noqa: E501

        The media's title.  # noqa: E501

        :return: The title of this MediaPreview.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this MediaPreview.

        The media's title.  # noqa: E501

        :param title: The title of this MediaPreview.  # noqa: E501
        :type: str
        """
        if title is None:
            raise ValueError(
                "Invalid value for `title`, must not be `None`"
            )  # noqa: E501

        self._title = title

    @property
    def description(self):
        """Gets the description of this MediaPreview.  # noqa: E501

        The media's description.  # noqa: E501

        :return: The description of this MediaPreview.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this MediaPreview.

        The media's description.  # noqa: E501

        :param description: The description of this MediaPreview.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def file_name(self):
        """Gets the file_name of this MediaPreview.  # noqa: E501

        The media file's name.  # noqa: E501

        :return: The file_name of this MediaPreview.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this MediaPreview.

        The media file's name.  # noqa: E501

        :param file_name: The file_name of this MediaPreview.  # noqa: E501
        :type: str
        """
        if file_name is None:
            raise ValueError(
                "Invalid value for `file_name`, must not be `None`"
            )  # noqa: E501

        self._file_name = file_name

    @property
    def url(self):
        """Gets the url of this MediaPreview.  # noqa: E501

        The media file's url.  # noqa: E501

        :return: The url of this MediaPreview.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this MediaPreview.

        The media file's url.  # noqa: E501

        :param url: The url of this MediaPreview.  # noqa: E501
        :type: str
        """
        if url is None:
            raise ValueError(
                "Invalid value for `url`, must not be `None`"
            )  # noqa: E501

        self._url = url

    @property
    def mime_type(self):
        """Gets the mime_type of this MediaPreview.  # noqa: E501

        The media file's type.  # noqa: E501

        :return: The mime_type of this MediaPreview.  # noqa: E501
        :rtype: str
        """
        return self._mime_type

    @mime_type.setter
    def mime_type(self, mime_type):
        """Sets the mime_type of this MediaPreview.

        The media file's type.  # noqa: E501

        :param mime_type: The mime_type of this MediaPreview.  # noqa: E501
        :type: str
        """
        if mime_type is None:
            raise ValueError(
                "Invalid value for `mime_type`, must not be `None`"
            )  # noqa: E501

        self._mime_type = mime_type

    @property
    def is_secure(self):
        """Gets the is_secure of this MediaPreview.  # noqa: E501

        Whether the media is secure.  # noqa: E501

        :return: The is_secure of this MediaPreview.  # noqa: E501
        :rtype: bool
        """
        return self._is_secure

    @is_secure.setter
    def is_secure(self, is_secure):
        """Sets the is_secure of this MediaPreview.

        Whether the media is secure.  # noqa: E501

        :param is_secure: The is_secure of this MediaPreview.  # noqa: E501
        :type: bool
        """
        if is_secure is None:
            raise ValueError(
                "Invalid value for `is_secure`, must not be `None`"
            )  # noqa: E501

        self._is_secure = is_secure

    @property
    def thumbnail(self):
        """Gets the thumbnail of this MediaPreview.  # noqa: E501


        :return: The thumbnail of this MediaPreview.  # noqa: E501
        :rtype: BlockImage
        """
        return self._thumbnail

    @thumbnail.setter
    def thumbnail(self, thumbnail):
        """Sets the thumbnail of this MediaPreview.


        :param thumbnail: The thumbnail of this MediaPreview.  # noqa: E501
        :type: BlockImage
        """

        self._thumbnail = thumbnail

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(MediaPreview, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MediaPreview):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class PostShare(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "shared_by": "UserReference",
        "shared_at": "datetime",
        "shared_to": "CommunityInfo",
        "site_id": "str",
        "is_pinned": "bool",
        "can_pin": "bool",
        "can_unshare": "bool",
    }

    attribute_map = {
        "shared_by": "sharedBy",
        "shared_at": "sharedAt",
        "shared_to": "sharedTo",
        "site_id": "siteId",
        "is_pinned": "isPinned",
        "can_pin": "canPin",
        "can_unshare": "canUnshare",
    }

    def __init__(
        self,
        shared_by=None,
        shared_at=None,
        shared_to=None,
        site_id=None,
        is_pinned=None,
        can_pin=None,
        can_unshare=None,
    ):  # noqa: E501
        """PostShare - a model defined in Swagger"""  # noqa: E501
        self._shared_by = None
        self._shared_at = None
        self._shared_to = None
        self._site_id = None
        self._is_pinned = None
        self._can_pin = None
        self._can_unshare = None
        self.discriminator = None
        self.shared_by = shared_by
        self.shared_at = shared_at
        self.shared_to = shared_to
        self.site_id = site_id
        self.is_pinned = is_pinned
        self.can_pin = can_pin
        self.can_unshare = can_unshare

    @property
    def shared_by(self):
        """Gets the shared_by of this PostShare.  # noqa: E501


        :return: The shared_by of this PostShare.  # noqa: E501
        :rtype: UserReference
        """
        return self._shared_by

    @shared_by.setter
    def shared_by(self, shared_by):
        """Sets the shared_by of this PostShare.


        :param shared_by: The shared_by of this PostShare.  # noqa: E501
        :type: UserReference
        """
        if shared_by is None:
            raise ValueError(
                "Invalid value for `shared_by`, must not be `None`"
            )  # noqa: E501

        self._shared_by = shared_by

    @property
    def shared_at(self):
        """Gets the shared_at of this PostShare.  # noqa: E501

        The date and time when the post was shared to the community.  # noqa: E501

        :return: The shared_at of this PostShare.  # noqa: E501
        :rtype: datetime
        """
        return self._shared_at

    @shared_at.setter
    def shared_at(self, shared_at):
        """Sets the shared_at of this PostShare.

        The date and time when the post was shared to the community.  # noqa: E501

        :param shared_at: The shared_at of this PostShare.  # noqa: E501
        :type: datetime
        """
        if shared_at is None:
            raise ValueError(
                "Invalid value for `shared_at`, must not be `None`"
            )  # noqa: E501

        self._shared_at = shared_at

    @property
    def shared_to(self):
        """Gets the shared_to of this PostShare.  # noqa: E501


        :return: The shared_to of this PostShare.  # noqa: E501
        :rtype: CommunityInfo
        """
        return self._shared_to

    @shared_to.setter
    def shared_to(self, shared_to):
        """Sets the shared_to of this PostShare.


        :param shared_to: The shared_to of this PostShare.  # noqa: E501
        :type: CommunityInfo
        """
        if shared_to is None:
            raise ValueError(
                "Invalid value for `shared_to`, must not be `None`"
            )  # noqa: E501

        self._shared_to = shared_to

    @property
    def site_id(self):
        """Gets the site_id of this PostShare.  # noqa: E501

        The id of the site owning the community.  # noqa: E501

        :return: The site_id of this PostShare.  # noqa: E501
        :rtype: str
        """
        return self._site_id

    @site_id.setter
    def site_id(self, site_id):
        """Sets the site_id of this PostShare.

        The id of the site owning the community.  # noqa: E501

        :param site_id: The site_id of this PostShare.  # noqa: E501
        :type: str
        """
        if site_id is None:
            raise ValueError(
                "Invalid value for `site_id`, must not be `None`"
            )  # noqa: E501

        self._site_id = site_id

    @property
    def is_pinned(self):
        """Gets the is_pinned of this PostShare.  # noqa: E501

        Whether the post is pinned in the community.  # noqa: E501

        :return: The is_pinned of this PostShare.  # noqa: E501
        :rtype: bool
        """
        return self._is_pinned

    @is_pinned.setter
    def is_pinned(self, is_pinned):
        """Sets the is_pinned of this PostShare.

        Whether the post is pinned in the community.  # noqa: E501

        :param is_pinned: The is_pinned of this PostShare.  # noqa: E501
        :type: bool
        """
        if is_pinned is None:
            raise ValueError(
                "Invalid value for `is_pinned`, must not be `None`"
            )  # noqa: E501

        self._is_pinned = is_pinned

    @property
    def can_pin(self):
        """Gets the can_pin of this PostShare.  # noqa: E501

        Whether the user is allowed to pin or unpin the post in the community.  # noqa: E501

        :return: The can_pin of this PostShare.  # noqa: E501
        :rtype: bool
        """
        return self._can_pin

    @can_pin.setter
    def can_pin(self, can_pin):
        """Sets the can_pin of this PostShare.

        Whether the user is allowed to pin or unpin the post in the community.  # noqa: E501

        :param can_pin: The can_pin of this PostShare.  # noqa: E501
        :type: bool
        """
        if can_pin is None:
            raise ValueError(
                "Invalid value for `can_pin`, must not be `None`"
            )  # noqa: E501

        self._can_pin = can_pin

    @property
    def can_unshare(self):
        """Gets the can_unshare of this PostShare.  # noqa: E501

        Whether the user is allowed to remove the sharing of the post to the community.  # noqa: E501

        :return: The can_unshare of this PostShare.  # noqa: E501
        :rtype: bool
        """
        return self._can_unshare

    @can_unshare.setter
    def can_unshare(self, can_unshare):
        """Sets the can_unshare of this PostShare.

        Whether the user is allowed to remove the sharing of the post to the community.  # noqa: E501

        :param can_unshare: The can_unshare of this PostShare.  # noqa: E501
        :type: bool
        """
        if can_unshare is None:
            raise ValueError(
                "Invalid value for `can_unshare`, must not be `None`"
            )  # noqa: E501

        self._can_unshare = can_unshare

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(PostShare, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PostShare):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Error(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "links": "ErrorLinks",
        "status": "str",
        "code": "str",
        "title": "str",
        "detail": "str",
        "source": "ErrorSource",
        "meta": "str",
    }

    attribute_map = {
        "links": "links",
        "status": "status",
        "code": "code",
        "title": "title",
        "detail": "detail",
        "source": "source",
        "meta": "meta",
    }

    def __init__(
        self,
        links=None,
        status=None,
        code=None,
        title=None,
        detail=None,
        source=None,
        meta=None,
    ):  # noqa: E501
        """Error - a model defined in Swagger"""  # noqa: E501
        self._links = None
        self._status = None
        self._code = None
        self._title = None
        self._detail = None
        self._source = None
        self._meta = None
        self.discriminator = None
        if links is not None:
            self.links = links
        if status is not None:
            self.status = status
        self.code = code
        self.title = title
        self.detail = detail
        if source is not None:
            self.source = source
        if meta is not None:
            self.meta = meta

    @property
    def links(self):
        """Gets the links of this Error.  # noqa: E501


        :return: The links of this Error.  # noqa: E501
        :rtype: ErrorLinks
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this Error.


        :param links: The links of this Error.  # noqa: E501
        :type: ErrorLinks
        """

        self._links = links

    @property
    def status(self):
        """Gets the status of this Error.  # noqa: E501

        The HTTP status code applicable to this problem, expressed as an integer value. Only provided if useful.   # noqa: E501

        :return: The status of this Error.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Error.

        The HTTP status code applicable to this problem, expressed as an integer value. Only provided if useful.   # noqa: E501

        :param status: The status of this Error.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def code(self):
        """Gets the code of this Error.  # noqa: E501

        An application-specific error code, expressed as a string value.   # noqa: E501

        :return: The code of this Error.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this Error.

        An application-specific error code, expressed as a string value.   # noqa: E501

        :param code: The code of this Error.  # noqa: E501
        :type: str
        """
        if code is None:
            raise ValueError(
                "Invalid value for `code`, must not be `None`"
            )  # noqa: E501

        self._code = code

    @property
    def title(self):
        """Gets the title of this Error.  # noqa: E501

        A short, human-readable summary of the problem that SHOULD NOT change from occurrence to occurrence of the problem, except for purposes of localization.   # noqa: E501

        :return: The title of this Error.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Error.

        A short, human-readable summary of the problem that SHOULD NOT change from occurrence to occurrence of the problem, except for purposes of localization.   # noqa: E501

        :param title: The title of this Error.  # noqa: E501
        :type: str
        """
        if title is None:
            raise ValueError(
                "Invalid value for `title`, must not be `None`"
            )  # noqa: E501

        self._title = title

    @property
    def detail(self):
        """Gets the detail of this Error.  # noqa: E501

        A human-readable explanation specific to this occurrence of the problem. Like title, this field’s value can be localized.   # noqa: E501

        :return: The detail of this Error.  # noqa: E501
        :rtype: str
        """
        return self._detail

    @detail.setter
    def detail(self, detail):
        """Sets the detail of this Error.

        A human-readable explanation specific to this occurrence of the problem. Like title, this field’s value can be localized.   # noqa: E501

        :param detail: The detail of this Error.  # noqa: E501
        :type: str
        """
        if detail is None:
            raise ValueError(
                "Invalid value for `detail`, must not be `None`"
            )  # noqa: E501

        self._detail = detail

    @property
    def source(self):
        """Gets the source of this Error.  # noqa: E501


        :return: The source of this Error.  # noqa: E501
        :rtype: ErrorSource
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this Error.


        :param source: The source of this Error.  # noqa: E501
        :type: ErrorSource
        """

        self._source = source

    @property
    def meta(self):
        """Gets the meta of this Error.  # noqa: E501

        A meta object containing non-standard meta-information about the error.  # noqa: E501

        :return: The meta of this Error.  # noqa: E501
        :rtype: str
        """
        return self._meta

    @meta.setter
    def meta(self, meta):
        """Sets the meta of this Error.

        A meta object containing non-standard meta-information about the error.  # noqa: E501

        :param meta: The meta of this Error.  # noqa: E501
        :type: str
        """

        self._meta = meta

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(Error, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Error):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

from .base_block import BaseBlock  # noqa: F401,E501


class BlockEventMetadata(BaseBlock):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "event_id": "str",
        "starts_at": "datetime",
        "ends_at": "datetime",
        "location": "str",
        "external_url": "str",
        "external_url_label": "EventLinkLabel",
        "attendees": "list[UserReference]",
        "attendees_count": "int",
        "is_user_registered": "bool",
        "add_to_google_calendar_url": "str",
        "add_to_outlook_calendar_url": "str",
        "organizers": "list[UserReference]",
        "title": "str",
        "intro": "str",
    }
    if hasattr(BaseBlock, "swagger_types"):
        swagger_types.update(BaseBlock.swagger_types)

    attribute_map = {
        "event_id": "eventId",
        "starts_at": "startsAt",
        "ends_at": "endsAt",
        "location": "location",
        "external_url": "externalUrl",
        "external_url_label": "externalUrlLabel",
        "attendees": "attendees",
        "attendees_count": "attendeesCount",
        "is_user_registered": "isUserRegistered",
        "add_to_google_calendar_url": "addToGoogleCalendarUrl",
        "add_to_outlook_calendar_url": "addToOutlookCalendarUrl",
        "organizers": "organizers",
        "title": "title",
        "intro": "intro",
    }
    if hasattr(BaseBlock, "attribute_map"):
        attribute_map.update(BaseBlock.attribute_map)

    def __init__(
        self,
        event_id=None,
        starts_at=None,
        ends_at=None,
        location=None,
        external_url=None,
        external_url_label=None,
        attendees=None,
        attendees_count=None,
        is_user_registered=None,
        add_to_google_calendar_url=None,
        add_to_outlook_calendar_url=None,
        organizers=None,
        title=None,
        intro=None,
        *args,
        **kwargs
    ):  # noqa: E501
        """BlockEventMetadata - a model defined in Swagger"""  # noqa: E501
        self._event_id = None
        self._starts_at = None
        self._ends_at = None
        self._location = None
        self._external_url = None
        self._external_url_label = None
        self._attendees = None
        self._attendees_count = None
        self._is_user_registered = None
        self._add_to_google_calendar_url = None
        self._add_to_outlook_calendar_url = None
        self._organizers = None
        self._title = None
        self._intro = None
        self.discriminator = None
        if event_id is not None:
            self.event_id = event_id
        self.starts_at = starts_at
        self.ends_at = ends_at
        if location is not None:
            self.location = location
        if external_url is not None:
            self.external_url = external_url
        if external_url_label is not None:
            self.external_url_label = external_url_label
        if attendees is not None:
            self.attendees = attendees
        if attendees_count is not None:
            self.attendees_count = attendees_count
        self.is_user_registered = is_user_registered
        self.add_to_google_calendar_url = add_to_google_calendar_url
        self.add_to_outlook_calendar_url = add_to_outlook_calendar_url
        self.organizers = organizers
        self.title = title
        if intro is not None:
            self.intro = intro
        BaseBlock.__init__(self, *args, **kwargs)

    @property
    def event_id(self):
        """Gets the event_id of this BlockEventMetadata.  # noqa: E501

        The event's id.  # noqa: E501

        :return: The event_id of this BlockEventMetadata.  # noqa: E501
        :rtype: str
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this BlockEventMetadata.

        The event's id.  # noqa: E501

        :param event_id: The event_id of this BlockEventMetadata.  # noqa: E501
        :type: str
        """

        self._event_id = event_id

    @property
    def starts_at(self):
        """Gets the starts_at of this BlockEventMetadata.  # noqa: E501

        The event's start date and time  # noqa: E501

        :return: The starts_at of this BlockEventMetadata.  # noqa: E501
        :rtype: datetime
        """
        return self._starts_at

    @starts_at.setter
    def starts_at(self, starts_at):
        """Sets the starts_at of this BlockEventMetadata.

        The event's start date and time  # noqa: E501

        :param starts_at: The starts_at of this BlockEventMetadata.  # noqa: E501
        :type: datetime
        """
        if starts_at is None:
            raise ValueError(
                "Invalid value for `starts_at`, must not be `None`"
            )  # noqa: E501

        self._starts_at = starts_at

    @property
    def ends_at(self):
        """Gets the ends_at of this BlockEventMetadata.  # noqa: E501

        The event's end date and time  # noqa: E501

        :return: The ends_at of this BlockEventMetadata.  # noqa: E501
        :rtype: datetime
        """
        return self._ends_at

    @ends_at.setter
    def ends_at(self, ends_at):
        """Sets the ends_at of this BlockEventMetadata.

        The event's end date and time  # noqa: E501

        :param ends_at: The ends_at of this BlockEventMetadata.  # noqa: E501
        :type: datetime
        """
        if ends_at is None:
            raise ValueError(
                "Invalid value for `ends_at`, must not be `None`"
            )  # noqa: E501

        self._ends_at = ends_at

    @property
    def location(self):
        """Gets the location of this BlockEventMetadata.  # noqa: E501

        The event's location, e.g. Yellow Meeting Room. Not to be confused with a localization. Not translatable either.   # noqa: E501

        :return: The location of this BlockEventMetadata.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this BlockEventMetadata.

        The event's location, e.g. Yellow Meeting Room. Not to be confused with a localization. Not translatable either.   # noqa: E501

        :param location: The location of this BlockEventMetadata.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def external_url(self):
        """Gets the external_url of this BlockEventMetadata.  # noqa: E501

        The url used to access an online event  # noqa: E501

        :return: The external_url of this BlockEventMetadata.  # noqa: E501
        :rtype: str
        """
        return self._external_url

    @external_url.setter
    def external_url(self, external_url):
        """Sets the external_url of this BlockEventMetadata.

        The url used to access an online event  # noqa: E501

        :param external_url: The external_url of this BlockEventMetadata.  # noqa: E501
        :type: str
        """

        self._external_url = external_url

    @property
    def external_url_label(self):
        """Gets the external_url_label of this BlockEventMetadata.  # noqa: E501


        :return: The external_url_label of this BlockEventMetadata.  # noqa: E501
        :rtype: EventLinkLabel
        """
        return self._external_url_label

    @external_url_label.setter
    def external_url_label(self, external_url_label):
        """Sets the external_url_label of this BlockEventMetadata.


        :param external_url_label: The external_url_label of this BlockEventMetadata.  # noqa: E501
        :type: EventLinkLabel
        """

        self._external_url_label = external_url_label

    @property
    def attendees(self):
        """Gets the attendees of this BlockEventMetadata.  # noqa: E501

        Four attendees of the event (ordered by emails)  # noqa: E501

        :return: The attendees of this BlockEventMetadata.  # noqa: E501
        :rtype: list[UserReference]
        """
        return self._attendees

    @attendees.setter
    def attendees(self, attendees):
        """Sets the attendees of this BlockEventMetadata.

        Four attendees of the event (ordered by emails)  # noqa: E501

        :param attendees: The attendees of this BlockEventMetadata.  # noqa: E501
        :type: list[UserReference]
        """

        self._attendees = attendees

    @property
    def attendees_count(self):
        """Gets the attendees_count of this BlockEventMetadata.  # noqa: E501

        The total number of attendees  # noqa: E501

        :return: The attendees_count of this BlockEventMetadata.  # noqa: E501
        :rtype: int
        """
        return self._attendees_count

    @attendees_count.setter
    def attendees_count(self, attendees_count):
        """Sets the attendees_count of this BlockEventMetadata.

        The total number of attendees  # noqa: E501

        :param attendees_count: The attendees_count of this BlockEventMetadata.  # noqa: E501
        :type: int
        """

        self._attendees_count = attendees_count

    @property
    def is_user_registered(self):
        """Gets the is_user_registered of this BlockEventMetadata.  # noqa: E501

        Whether the current user is registered for the event.  # noqa: E501

        :return: The is_user_registered of this BlockEventMetadata.  # noqa: E501
        :rtype: bool
        """
        return self._is_user_registered

    @is_user_registered.setter
    def is_user_registered(self, is_user_registered):
        """Sets the is_user_registered of this BlockEventMetadata.

        Whether the current user is registered for the event.  # noqa: E501

        :param is_user_registered: The is_user_registered of this BlockEventMetadata.  # noqa: E501
        :type: bool
        """
        if is_user_registered is None:
            raise ValueError(
                "Invalid value for `is_user_registered`, must not be `None`"
            )  # noqa: E501

        self._is_user_registered = is_user_registered

    @property
    def add_to_google_calendar_url(self):
        """Gets the add_to_google_calendar_url of this BlockEventMetadata.  # noqa: E501

        An \"Add to my calendar\" URL for Google Calendar  # noqa: E501

        :return: The add_to_google_calendar_url of this BlockEventMetadata.  # noqa: E501
        :rtype: str
        """
        return self._add_to_google_calendar_url

    @add_to_google_calendar_url.setter
    def add_to_google_calendar_url(self, add_to_google_calendar_url):
        """Sets the add_to_google_calendar_url of this BlockEventMetadata.

        An \"Add to my calendar\" URL for Google Calendar  # noqa: E501

        :param add_to_google_calendar_url: The add_to_google_calendar_url of this BlockEventMetadata.  # noqa: E501
        :type: str
        """
        if add_to_google_calendar_url is None:
            raise ValueError(
                "Invalid value for `add_to_google_calendar_url`, must not be `None`"
            )  # noqa: E501

        self._add_to_google_calendar_url = add_to_google_calendar_url

    @property
    def add_to_outlook_calendar_url(self):
        """Gets the add_to_outlook_calendar_url of this BlockEventMetadata.  # noqa: E501

        An \"Add to my calendar\" URL for outlook Calendar  # noqa: E501

        :return: The add_to_outlook_calendar_url of this BlockEventMetadata.  # noqa: E501
        :rtype: str
        """
        return self._add_to_outlook_calendar_url

    @add_to_outlook_calendar_url.setter
    def add_to_outlook_calendar_url(self, add_to_outlook_calendar_url):
        """Sets the add_to_outlook_calendar_url of this BlockEventMetadata.

        An \"Add to my calendar\" URL for outlook Calendar  # noqa: E501

        :param add_to_outlook_calendar_url: The add_to_outlook_calendar_url of this BlockEventMetadata.  # noqa: E501
        :type: str
        """
        if add_to_outlook_calendar_url is None:
            raise ValueError(
                "Invalid value for `add_to_outlook_calendar_url`, must not be `None`"
            )  # noqa: E501

        self._add_to_outlook_calendar_url = add_to_outlook_calendar_url

    @property
    def organizers(self):
        """Gets the organizers of this BlockEventMetadata.  # noqa: E501

        The organizers of the event.  # noqa: E501

        :return: The organizers of this BlockEventMetadata.  # noqa: E501
        :rtype: list[UserReference]
        """
        return self._organizers

    @organizers.setter
    def organizers(self, organizers):
        """Sets the organizers of this BlockEventMetadata.

        The organizers of the event.  # noqa: E501

        :param organizers: The organizers of this BlockEventMetadata.  # noqa: E501
        :type: list[UserReference]
        """
        if organizers is None:
            raise ValueError(
                "Invalid value for `organizers`, must not be `None`"
            )  # noqa: E501

        self._organizers = organizers

    @property
    def title(self):
        """Gets the title of this BlockEventMetadata.  # noqa: E501

        The title of the event.  # noqa: E501

        :return: The title of this BlockEventMetadata.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this BlockEventMetadata.

        The title of the event.  # noqa: E501

        :param title: The title of this BlockEventMetadata.  # noqa: E501
        :type: str
        """
        if title is None:
            raise ValueError(
                "Invalid value for `title`, must not be `None`"
            )  # noqa: E501

        self._title = title

    @property
    def intro(self):
        """Gets the intro of this BlockEventMetadata.  # noqa: E501

        The event introduction.  # noqa: E501

        :return: The intro of this BlockEventMetadata.  # noqa: E501
        :rtype: str
        """
        return self._intro

    @intro.setter
    def intro(self, intro):
        """Sets the intro of this BlockEventMetadata.

        The event introduction.  # noqa: E501

        :param intro: The intro of this BlockEventMetadata.  # noqa: E501
        :type: str
        """

        self._intro = intro

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(BlockEventMetadata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BlockEventMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from abc import ABC, abstractmethod
from dataclasses import dataclass, field
from typing import Any, Mapping


@dataclass(frozen=True)
class Request:
    # The HTTP method, usually GET, POST, PUT or PATCH
    method: str
    # The requested URL
    url: str
    # The query parameters (?key=value)
    params: Mapping[str, str] = field(default_factory=dict)
    # The extra headers required to process the request
    headers: Mapping[str, str] = field(default_factory=dict)
    # The JSON content of the request
    json: Any = None


@dataclass(frozen=True)
class Response:
    status_code: int
    headers: Mapping[str, str]
    json: Any


class IClient(ABC):
    """
    The generic HTTP client for LumApps
    The implementation must handle authentification and specifics if necessary
    """

    @abstractmethod
    def request(self, request: Request, **kwargs: Any) -> Response:  # pragma: no cover
        """
        kwargs should be used for very niche behavior and not relied on extensively
        Most, if not all, implementations should NOT need to use it
        """
        pass



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class MetadataReference(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "metadata_id": "str",
        "name": "str",
        "root_id": "str",
        "root_name": "str",
    }

    attribute_map = {
        "metadata_id": "metadataId",
        "name": "name",
        "root_id": "rootId",
        "root_name": "rootName",
    }

    def __init__(
        self, metadata_id=None, name=None, root_id=None, root_name=None
    ):  # noqa: E501
        """MetadataReference - a model defined in Swagger"""  # noqa: E501
        self._metadata_id = None
        self._name = None
        self._root_id = None
        self._root_name = None
        self.discriminator = None
        self.metadata_id = metadata_id
        self.name = name
        if root_id is not None:
            self.root_id = root_id
        if root_name is not None:
            self.root_name = root_name

    @property
    def metadata_id(self):
        """Gets the metadata_id of this MetadataReference.  # noqa: E501

        The metadata's id.  # noqa: E501

        :return: The metadata_id of this MetadataReference.  # noqa: E501
        :rtype: str
        """
        return self._metadata_id

    @metadata_id.setter
    def metadata_id(self, metadata_id):
        """Sets the metadata_id of this MetadataReference.

        The metadata's id.  # noqa: E501

        :param metadata_id: The metadata_id of this MetadataReference.  # noqa: E501
        :type: str
        """
        if metadata_id is None:
            raise ValueError(
                "Invalid value for `metadata_id`, must not be `None`"
            )  # noqa: E501

        self._metadata_id = metadata_id

    @property
    def name(self):
        """Gets the name of this MetadataReference.  # noqa: E501

        The metadata's name.  # noqa: E501

        :return: The name of this MetadataReference.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MetadataReference.

        The metadata's name.  # noqa: E501

        :param name: The name of this MetadataReference.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError(
                "Invalid value for `name`, must not be `None`"
            )  # noqa: E501

        self._name = name

    @property
    def root_id(self):
        """Gets the root_id of this MetadataReference.  # noqa: E501

        The id of the metadata's tree root.  # noqa: E501

        :return: The root_id of this MetadataReference.  # noqa: E501
        :rtype: str
        """
        return self._root_id

    @root_id.setter
    def root_id(self, root_id):
        """Sets the root_id of this MetadataReference.

        The id of the metadata's tree root.  # noqa: E501

        :param root_id: The root_id of this MetadataReference.  # noqa: E501
        :type: str
        """

        self._root_id = root_id

    @property
    def root_name(self):
        """Gets the root_name of this MetadataReference.  # noqa: E501

        The name of the metadata's tree root.  # noqa: E501

        :return: The root_name of this MetadataReference.  # noqa: E501
        :rtype: str
        """
        return self._root_name

    @root_name.setter
    def root_name(self, root_name):
        """Sets the root_name of this MetadataReference.

        The name of the metadata's tree root.  # noqa: E501

        :param root_name: The root_name of this MetadataReference.  # noqa: E501
        :type: str
        """

        self._root_name = root_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(MetadataReference, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MetadataReference):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    CMS Contribution API

    The CMS Contribution API allows access and modification of Lumapps contents.   # noqa: E501

    OpenAPI spec version: 0.1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six


class Event(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "id": "str",
        "author": "UserReference",
        "organizers": "list[UserReference]",
        "starts_at": "datetime",
        "ends_at": "datetime",
        "location": "str",
        "external_url": "str",
        "external_url_label": "OneOfEventExternalUrlLabel",
        "created_at": "datetime",
        "updated_at": "datetime",
        "template_id": "str",
        "shares": "list[EventShare]",
        "can_edit": "bool",
        "is_user_registered": "bool",
        "structured_content": "StructuredContent",
    }

    attribute_map = {
        "id": "id",
        "author": "author",
        "organizers": "organizers",
        "starts_at": "startsAt",
        "ends_at": "endsAt",
        "location": "location",
        "external_url": "externalUrl",
        "external_url_label": "externalUrlLabel",
        "created_at": "createdAt",
        "updated_at": "updatedAt",
        "template_id": "templateId",
        "shares": "shares",
        "can_edit": "canEdit",
        "is_user_registered": "isUserRegistered",
        "structured_content": "structuredContent",
    }

    def __init__(
        self,
        id=None,
        author=None,
        organizers=None,
        starts_at=None,
        ends_at=None,
        location=None,
        external_url=None,
        external_url_label=None,
        created_at=None,
        updated_at=None,
        template_id=None,
        shares=None,
        can_edit=None,
        is_user_registered=None,
        structured_content=None,
    ):  # noqa: E501
        """Event - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._author = None
        self._organizers = None
        self._starts_at = None
        self._ends_at = None
        self._location = None
        self._external_url = None
        self._external_url_label = None
        self._created_at = None
        self._updated_at = None
        self._template_id = None
        self._shares = None
        self._can_edit = None
        self._is_user_registered = None
        self._structured_content = None
        self.discriminator = None
        self.id = id
        self.author = author
        if organizers is not None:
            self.organizers = organizers
        self.starts_at = starts_at
        self.ends_at = ends_at
        if location is not None:
            self.location = location
        if external_url is not None:
            self.external_url = external_url
        if external_url_label is not None:
            self.external_url_label = external_url_label
        self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if template_id is not None:
            self.template_id = template_id
        if shares is not None:
            self.shares = shares
        if can_edit is not None:
            self.can_edit = can_edit
        if is_user_registered is not None:
            self.is_user_registered = is_user_registered
        if structured_content is not None:
            self.structured_content = structured_content

    @property
    def id(self):
        """Gets the id of this Event.  # noqa: E501

        The event id  # noqa: E501

        :return: The id of this Event.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Event.

        The event id  # noqa: E501

        :param id: The id of this Event.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def author(self):
        """Gets the author of this Event.  # noqa: E501


        :return: The author of this Event.  # noqa: E501
        :rtype: UserReference
        """
        return self._author

    @author.setter
    def author(self, author):
        """Sets the author of this Event.


        :param author: The author of this Event.  # noqa: E501
        :type: UserReference
        """
        if author is None:
            raise ValueError(
                "Invalid value for `author`, must not be `None`"
            )  # noqa: E501

        self._author = author

    @property
    def organizers(self):
        """Gets the organizers of this Event.  # noqa: E501

        The organizers of the event  # noqa: E501

        :return: The organizers of this Event.  # noqa: E501
        :rtype: list[UserReference]
        """
        return self._organizers

    @organizers.setter
    def organizers(self, organizers):
        """Sets the organizers of this Event.

        The organizers of the event  # noqa: E501

        :param organizers: The organizers of this Event.  # noqa: E501
        :type: list[UserReference]
        """

        self._organizers = organizers

    @property
    def starts_at(self):
        """Gets the starts_at of this Event.  # noqa: E501

        The event's start date and time  # noqa: E501

        :return: The starts_at of this Event.  # noqa: E501
        :rtype: datetime
        """
        return self._starts_at

    @starts_at.setter
    def starts_at(self, starts_at):
        """Sets the starts_at of this Event.

        The event's start date and time  # noqa: E501

        :param starts_at: The starts_at of this Event.  # noqa: E501
        :type: datetime
        """
        if starts_at is None:
            raise ValueError(
                "Invalid value for `starts_at`, must not be `None`"
            )  # noqa: E501

        self._starts_at = starts_at

    @property
    def ends_at(self):
        """Gets the ends_at of this Event.  # noqa: E501

        The event's end date and time  # noqa: E501

        :return: The ends_at of this Event.  # noqa: E501
        :rtype: datetime
        """
        return self._ends_at

    @ends_at.setter
    def ends_at(self, ends_at):
        """Sets the ends_at of this Event.

        The event's end date and time  # noqa: E501

        :param ends_at: The ends_at of this Event.  # noqa: E501
        :type: datetime
        """
        if ends_at is None:
            raise ValueError(
                "Invalid value for `ends_at`, must not be `None`"
            )  # noqa: E501

        self._ends_at = ends_at

    @property
    def location(self):
        """Gets the location of this Event.  # noqa: E501

        The event's location, e.g. Yellow Meeting Room. Not to be confused with a localization. Not translatable either.   # noqa: E501

        :return: The location of this Event.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this Event.

        The event's location, e.g. Yellow Meeting Room. Not to be confused with a localization. Not translatable either.   # noqa: E501

        :param location: The location of this Event.  # noqa: E501
        :type: str
        """

        self._location = location

    @property
    def external_url(self):
        """Gets the external_url of this Event.  # noqa: E501

        The url used to access an online event  # noqa: E501

        :return: The external_url of this Event.  # noqa: E501
        :rtype: str
        """
        return self._external_url

    @external_url.setter
    def external_url(self, external_url):
        """Sets the external_url of this Event.

        The url used to access an online event  # noqa: E501

        :param external_url: The external_url of this Event.  # noqa: E501
        :type: str
        """

        self._external_url = external_url

    @property
    def external_url_label(self):
        """Gets the external_url_label of this Event.  # noqa: E501


        :return: The external_url_label of this Event.  # noqa: E501
        :rtype: OneOfEventExternalUrlLabel
        """
        return self._external_url_label

    @external_url_label.setter
    def external_url_label(self, external_url_label):
        """Sets the external_url_label of this Event.


        :param external_url_label: The external_url_label of this Event.  # noqa: E501
        :type: OneOfEventExternalUrlLabel
        """

        self._external_url_label = external_url_label

    @property
    def created_at(self):
        """Gets the created_at of this Event.  # noqa: E501

        The event's creation date and time  # noqa: E501

        :return: The created_at of this Event.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Event.

        The event's creation date and time  # noqa: E501

        :param created_at: The created_at of this Event.  # noqa: E501
        :type: datetime
        """
        if created_at is None:
            raise ValueError(
                "Invalid value for `created_at`, must not be `None`"
            )  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this Event.  # noqa: E501

        The date and time when the event was last updated  # noqa: E501

        :return: The updated_at of this Event.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Event.

        The date and time when the event was last updated  # noqa: E501

        :param updated_at: The updated_at of this Event.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def template_id(self):
        """Gets the template_id of this Event.  # noqa: E501

        The id of the template used to display the event  # noqa: E501

        :return: The template_id of this Event.  # noqa: E501
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this Event.

        The id of the template used to display the event  # noqa: E501

        :param template_id: The template_id of this Event.  # noqa: E501
        :type: str
        """

        self._template_id = template_id

    @property
    def shares(self):
        """Gets the shares of this Event.  # noqa: E501


        :return: The shares of this Event.  # noqa: E501
        :rtype: list[EventShare]
        """
        return self._shares

    @shares.setter
    def shares(self, shares):
        """Sets the shares of this Event.


        :param shares: The shares of this Event.  # noqa: E501
        :type: list[EventShare]
        """

        self._shares = shares

    @property
    def can_edit(self):
        """Gets the can_edit of this Event.  # noqa: E501

        Whether the user doing the request can edit the event  # noqa: E501

        :return: The can_edit of this Event.  # noqa: E501
        :rtype: bool
        """
        return self._can_edit

    @can_edit.setter
    def can_edit(self, can_edit):
        """Sets the can_edit of this Event.

        Whether the user doing the request can edit the event  # noqa: E501

        :param can_edit: The can_edit of this Event.  # noqa: E501
        :type: bool
        """

        self._can_edit = can_edit

    @property
    def is_user_registered(self):
        """Gets the is_user_registered of this Event.  # noqa: E501

        Whether the user doing the request is registered in the event  # noqa: E501

        :return: The is_user_registered of this Event.  # noqa: E501
        :rtype: bool
        """
        return self._is_user_registered

    @is_user_registered.setter
    def is_user_registered(self, is_user_registered):
        """Sets the is_user_registered of this Event.

        Whether the user doing the request is registered in the event  # noqa: E501

        :param is_user_registered: The is_user_registered of this Event.  # noqa: E501
        :type: bool
        """

        self._is_user_registered = is_user_registered

    @property
    def structured_content(self):
        """Gets the structured_content of this Event.  # noqa: E501


        :return: The structured_content of this Event.  # noqa: E501
        :rtype: StructuredContent
        """
        return self._structured_content

    @structured_content.setter
    def structured_content(self, structured_content):
        """Sets the structured_content of this Event.


        :param structured_content: The structured_content of this Event.  # noqa: E501
        :type: StructuredContent
        """

        self._structured_content = structured_content

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(Event, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Event):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
